<?php
class hwd_vs_SConfig{ 

  // Stores the only allowable instance of this class.
  var $instanceConfig = null;

  // Member variables
  var $ffmpegpath = '/usr/local/bin/ffmpeg';
  var $flvtool2path = '/usr/bin/flvtool2';
  var $mencoderpath = '/usr/local/bin/mencoder';
  var $phppath = '/usr/bin/php';
  var $wgetpath = '/usr/bin/wget';
  var $qtfaststart = '/usr/local/bin/qt-faststart';

/**
  * get_instance
  *	Description:
  *		This function is used to instantiate the object
  * 		and ensure only one of this type exists at any
  *		time. It returns a reference to the only Config
  *		instance.
  *	Parameters:
  *		none
  *	Returns:
  *		Config
  **/

  function get_instance(){
    $instanceConfig = new hwd_vs_SConfig;
    return $instanceConfig;
  }

}
?>