<?php
/**
 *    @version [ Nightly Build ]
 *    @package hwdVideoShare
 *    @copyright (C) 2007 - 2011 Highwood Design
 *    @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 ***
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***
 *    New Language Definitions are located at bottom of file
 *    DEFINITIONS HAVE FORM
 *    ---------------------
 *    DEFINE("_HWDVIDS_NAV_VIDEOS","Videos"); // Videos
 *           \___________________/  \_____/      \____/
 *            |                 |    |    \_____  \   \_____________________
 *            | PHP LANGUAGE    |    | LANGUAGE \__ \    COPY OF ORIGINAL   |
 *            | DEFINTIONS      |    | TRANSLATION |  \  ENGLISH DEFINITION |
 *            |_________________|    |_____________|    \___________________|
 ***
 *    TRANSLATOR CREDITS CAN GO HERE::
 *    ORIGINAL ENGLISH FILE BY HIGHWOOD DESIGN
 **/
defined( '_JEXEC' ) or die( 'Direct Access to this location is not allowed.' );

/**
 *    ** IMPORTANT ** DO NOT ADD DASHES (-) OR SPACES ( ) INTO THE SEF PHRASES
 **/

DEFINE("_HWDVS_SEF_FP","frontpage");
DEFINE("_HWDVS_SEF_VIDEOS","videos");
DEFINE("_HWDVS_SEF_EDITVIDEO","editvideo");
DEFINE("_HWDVS_SEF_FEATUREDVIDEOS","featuredvideos");
DEFINE("_HWDVS_SEF_VIEWVIDEO","viewvideo");
DEFINE("_HWDVS_SEF_CATEGORIES","categories");
DEFINE("_HWDVS_SEF_VIEWCATEGORY","viewcategory");
DEFINE("_HWDVS_SEF_GROUPS","groups");
DEFINE("_HWDVS_SEF_CREATEGROUP","creategroup");
DEFINE("_HWDVS_SEF_EDITGROUP","editgroup");
DEFINE("_HWDVS_SEF_FEATUREDGROUPS","featuredgroups");
DEFINE("_HWDVS_SEF_VIEWGROUP","viewgroup");
DEFINE("_HWDVS_SEF_YV","yourvideos");
DEFINE("_HWDVS_SEF_YF","yourfavourites");
DEFINE("_HWDVS_SEF_YG","yourgroups");
DEFINE("_HWDVS_SEF_YM","yourmemberships");
DEFINE("_HWDVS_SEF_CG","creategroup");
DEFINE("_HWDVS_SEF_RSS","rss");
DEFINE("_HWDVS_SEF_VC","videocategory");
DEFINE("_HWDVS_SEF_UPLOAD","upload");
DEFINE("_HWDVS_SEF_UPLOADEDP","videouploaded");
DEFINE("_HWDVS_SEF_UPLOADEDF","videouploadedflash");
DEFINE("_HWDVS_SEF_UPLOADEDB","videouploadedphp");
DEFINE("_HWDVS_SEF_ADDED","videoadded");
DEFINE("_HWDVS_SEF_NV","nextvideo");
DEFINE("_HWDVS_SEF_PV","previousvideo");
DEFINE("_HWDVS_SEF_DR","displayresults");
DEFINE("_HWDVS_SEF_SEARCH","search");
DEFINE("_HWDVS_SEF_VIEWCHANNEL","channel");


DEFINE("_HWDVIDS_VYV","View Your Videos");
DEFINE("_HWDVIDS_ALLVIDEOS","All Videos");
DEFINE("_HWDVIDS_UPLOADVIDEOS","Upload Videos");
DEFINE("_HWDVIDS_VIEWALL","View All");
