{* 
//////
//    @version [ Nightly Build ]
//    @package hwdVideoShare
//    @copyright (C) 2007 - 2011 Highwood Design
//    @license http://creativecommons.org/licenses/by-nc-nd/3.0/
//////
*}

{include file='admin_header.tpl'}

<table cellpadding="0" cellspacing="0" border="0" width="100%" class="adminform">
  <tr>
    <td align="left">
    <h2>hwdVideoShare Plugins</h2>
    <p>hwdVideoShare Plugins are controlled using the Joomla Plugin Manager.</p>
    <p><a href="{$mosConfig_live_site}/administrator/index.php?option=com_plugins&filter_type=hwdvs-language">Click here to view the Language plugins</a></p>
    <p><a href="{$mosConfig_live_site}/administrator/index.php?option=com_plugins&filter_type=hwdvs-template">Click here to view the Template plugins</a></p>
    <p><a href="{$mosConfig_live_site}/administrator/index.php?option=com_plugins&filter_type=hwdvs-thirdparty">Click here to view the Third Party plugins</a></p>
    <p><a href="{$mosConfig_live_site}/administrator/index.php?option=com_plugins&filter_type=hwdvs-videoplayer">Click here to view the Video Player plugins</a></p>
    <p><a href="{$mosConfig_live_site}/administrator/index.php?option=com_plugins&filter_type=hwdvs-storage">Click here to view the Storage plugins</a></p>
    </td>
  </tr>
</table>

{include file='admin_footer.tpl'}
