<?php
/**
 *    @version [ Nightly Build ]
 *    @package hwdVideoShare
 *    @copyright (C) 2007 - 2011 Highwood Design
 *    @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 ***
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***
 *    New Language Definitions are located at bottom of file
 *    DEFINITIONS HAVE FORM
 *    ---------------------
 *    DEFINE("_HWDVIDS_NAV_VIDEOS","Videos"); // Videos
 *           \___________________/  \_____/      \____/
 *            |                 |    |    \_____  \   \_____________________
 *            | PHP LANGUAGE    |    | LANGUAGE \__ \    COPY OF ORIGINAL   |
 *            | DEFINTIONS      |    | TRANSLATION |  \  ENGLISH DEFINITION |
 *            |_________________|    |_____________|    \___________________|
 ***
 *    TRANSLATOR CREDITS CAN GO HERE::
 *    ORIGINAL ENGLISH FILE BY HIGHWOOD DESIGN
 **/
defined( '_JEXEC' ) or die( 'Direct Access to this location is not allowed.' );

DEFINE("_ADMIN_HWDVIDS_SETT_TABLAYOUT","Layout");
DEFINE("_ADMIN_HWDVIDS_SETT_VIDEOS","Video Lists");
DEFINE("_ADMIN_HWDVIDS_SETT_VPP","Videos Per Page");
DEFINE("_ADMIN_HWDVIDS_SETT_VPP_DESC","Set the number of videos displayed per page");
DEFINE("_ADMIN_HWDVIDS_SETT_FVIDS","Featured Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_FVIDS_DESC","Set the number of featured videos displayed on the component homepage");
DEFINE("_ADMIN_HWDVIDS_SETT_GROUPS","Group Lists");
DEFINE("_ADMIN_HWDVIDS_SETT_GPP","Groups Per Page");
DEFINE("_ADMIN_HWDVIDS_SETT_GPP_DESC","Set the number of groups displayed per page");
DEFINE("_ADMIN_HWDVIDS_SETT_FGROUPS","Featured Groups");
DEFINE("_ADMIN_HWDVIDS_SETT_FGROUPS_DESC","Set the number of featured groups displayed on the group homepage");
DEFINE("_ADMIN_HWDVIDS_SETT_COMMENTS","Comment Lists");
DEFINE("_ADMIN_HWDVIDS_SETT_CPP","Comments Per Page");
DEFINE("_ADMIN_HWDVIDS_SETT_CPP_DESC","Set the number of comments displayed per page");
DEFINE("_ADMIN_HWDVIDS_SETT_PLUGINS","Plugin Management");
DEFINE("_ADMIN_HWDVIDS_SETT_TEMPLATE","Select Template");
DEFINE("_ADMIN_HWDVIDS_SETT_TEMPLATE_DESC","Choose the hwdVideoShare template plugin. To add more templates, install template plugins through the plugin manager.");
DEFINE("_ADMIN_HWDVIDS_SETT_LANGUAGE","Select Language");
DEFINE("_ADMIN_HWDVIDS_SETT_ROUNDEDC","Rounded Corners");
DEFINE("_ADMIN_HWDVIDS_SETT_RADIUSRC","Rounded Corner Radius");
DEFINE("_ADMIN_HWDVIDS_SETT_RADIUSRC_DESC","Choose the radius of the rounded corners (in pixels)");
DEFINE("_ADMIN_HWDVIDS_SETT_LOGS","Video Conversion Logs");
DEFINE("_ADMIN_HWDVIDS_SETT_LOGCONVERT","Log Video Conversions?");
DEFINE("_ADMIN_HWDVIDS_SETT_DEBUG","Video Conversions Debug");
DEFINE("_ADMIN_HWDVIDS_SETT_DEBUGCONVERT","Debug Video Conversions?");
DEFINE("_ADMIN_HWDVIDS_SETT_DEBUG_DESC","Dump conversion output to screen during video conversions to debug");
DEFINE("_ADMIN_HWDVIDS_SETT_ORIGINALS","Original Video");
DEFINE("_ADMIN_HWDVIDS_SETT_DELETEO","Delete Original Videos?");
DEFINE("_ADMIN_HWDVIDS_SETT_DELETEO_DESC","Delete the original video files after successful conversion (Highly Recommended)");
DEFINE("_ADMIN_HWDVIDS_SETT_NOTIFICATIONS","Administrator Notifications");
DEFINE("_ADMIN_HWDVIDS_SETT_NOTIFYVID","Notify after new video upload?");
DEFINE("_ADMIN_HWDVIDS_SETT_NOTIFYVID_DESC","Send a notification email when a user uploads a video");
DEFINE("_ADMIN_HWDVIDS_SETT_NOTIFYG","Notify after new group creation?");
DEFINE("_ADMIN_HWDVIDS_SETT_NOTIFYG_DESC","Send a notification email when a user creates a group");
DEFINE("_ADMIN_HWDVIDS_SETT_NOTIFYC","Notify after new comment?");
DEFINE("_ADMIN_HWDVIDS_SETT_NOTIFYC_DESC","Send a notification email when a user writes a comment");
DEFINE("_ADMIN_HWDVIDS_SETT_SENTTO","Sent notifications to:");
DEFINE("_ADMIN_HWDVIDS_SETT_SENDTO_DESC","The email address that should receive the notification emails");
DEFINE("_ADMIN_HWDVIDS_SETT_INTEGRATIONS","Integrations");
DEFINE("_ADMIN_HWDVIDS_SETT_ACCESS","Access");
DEFINE("_ADMIN_HWDVIDS_SETT_GUESTCOMMS","Allow Guest Comments?");
DEFINE("_ADMIN_HWDVIDS_SETT_GUESTCOMMS_DESC","Allow users who are not logged in to add video/group comments");
DEFINE("_ADMIN_HWDVIDS_SETT_01","1");
DEFINE("_ADMIN_HWDVIDS_SETT_02","2");
DEFINE("_ADMIN_HWDVIDS_SETT_03","3");
DEFINE("_ADMIN_HWDVIDS_SETT_04","4");
DEFINE("_ADMIN_HWDVIDS_SETT_05","5");
DEFINE("_ADMIN_HWDVIDS_SETT_06","6");
DEFINE("_ADMIN_HWDVIDS_SETT_07","7");
DEFINE("_ADMIN_HWDVIDS_SETT_08","8");
DEFINE("_ADMIN_HWDVIDS_SETT_09","9");
DEFINE("_ADMIN_HWDVIDS_SETT_10","10");
DEFINE("_ADMIN_HWDVIDS_SETT_15","15");
DEFINE("_ADMIN_HWDVIDS_SETT_20","20");
DEFINE("_ADMIN_HWDVIDS_SETT_25","25");
DEFINE("_ADMIN_HWDVIDS_SETT_30","30");
DEFINE("_ADMIN_HWDVIDS_SETT_35","35");
DEFINE("_ADMIN_HWDVIDS_SETT_40","40");
DEFINE("_ADMIN_HWDVIDS_SETT_45","45");
DEFINE("_ADMIN_HWDVIDS_SETT_50","50");
DEFINE("_ADMIN_HWDVIDS_SETT_APPROVALS","Auto Approvals");
DEFINE("_ADMIN_HWDVIDS_SETT_AA3VIDS","Auto-approve 3rd Party Videos?");
DEFINE("_ADMIN_HWDVIDS_SETT_AAGROUPS","Auto-approve Groups?");
DEFINE("_ADMIN_HWDVIDS_SETT_AACOMMS","Auto-approve Comments?");
DEFINE("_ADMIN_HWDVIDS_SETT_AAVIDS_DESC","Should videos be automatically approved after conversion?");
DEFINE("_ADMIN_HWDVIDS_SETT_AA3VIDS_DESC","Should third party videos (from YouTube etc) be automatically approved?");
DEFINE("_ADMIN_HWDVIDS_SETT_AAGROUPS_DESC","Should groups be automatically approved after they are created by users?");
DEFINE("_ADMIN_HWDVIDS_SETT_LOCALUPLD","Local File Uploads");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLELCOAL","Disable Local File Uploads");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLELCOAL_DESC","Disabling this feature will prevent people uploading video files from their local computers. They will only be able to add videos from third party video websites like YouTube. If you disable this remember to enable at least one third party video website.");
DEFINE("_ADMIN_HWDVIDS_SETT_THIRDPARTYVSITES","Third Party Video Sites");
DEFINE("_ADMIN_HWDVIDS_SETT_ALLOWYOUTUBE","Allow YouTube Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_ALLOWYOUTUBE_DESC","Allow users to add videos from YouTube");
DEFINE("_ADMIN_HWDVIDS_SETT_GOOGLE","Allow Google Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_GOOGLE_DESC","Allow users to add videos from Google");
DEFINE("_ADMIN_HWDVIDS_SETT_EYESPOT","Allow Eyespot Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_EYESPOT_DESC","Allow users to add videos from Eyespot");
DEFINE("_ADMIN_HWDVIDS_SETT_JUMPCUT","Allow Jumpcut Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_JUMPCUT_DESC","Allow users to add videos from Jumpcut");
DEFINE("_ADMIN_HWDVIDS_SETT_REVVER","Allow Revver Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_REVVER_DESC","Allow users to add videos from Revver");
DEFINE("_ADMIN_HWDVIDS_SETT_VIMEO","Allow Vimeo Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_VIMEO_DESC","Allow users to add videos from Vimeo");
DEFINE("_ADMIN_HWDVIDS_SETT_BLIPTV","Allow Blip.tv Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_BLIPTV_DESC","Allow users to add videos from Blip.tv");
DEFINE("_ADMIN_HWDVIDS_SETT_STAGE6","Allow Stage6 [DivX] Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_STAGE6_DESC","Allow users to add videos from Stage6 [This will require the user to use the DivX web player]");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAYER","Video Player Settings");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_WIDTH","Video Player Width (px)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_WIDTH_DESC","Forces the video player's width in pixels (eg 450px). Note this will be used for all third party video widths also.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_HEIGHT","Video Player Height (px)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_HEIGHT_DESC","Forces the video player's height in pixels (eg 450px). Note this will be used for all third party video height also.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_AUTOPLAY","Autoplay");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_AUTOPLAY_DESC","Autoplay the video when page loads");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_AUTOLOAD","Autoload");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_AUTOLOAD_DESC","Autoload the video when the page loads");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUFFER","Buffer Time (secs)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUFFER_DESC","The number of seconds to buffer. By default set to 5.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWSTOP","Show Stop Button");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWSTOP_DESC","Show the stop button on the video player");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWVOL","Show Volume Slider");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWVOL_DESC","Show the volume slider on the video player");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWTIME","Show Time");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWTIME_DESC","Show the video time of the current position");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_LOOP","Loop Movie");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_LOOP_DESC","Loop movie when finished");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_IMAGE","Logo Image and Position");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_IMAGE_DESC","Load an image over the video and place it at the coordinate x and y (for example url|x|y)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_COLOR","Player Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_COLOR_DESC","The background colour of the player bar in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_LDCOLOR","Loading Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_LDCOLOR_DESC","The colour of loading bar in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BGCOLOR0","Background Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BGCOLOR0_DESC","The background colour in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BGCOLOR1","Gradient Colour 1");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BGCOLOR1_DESC","The first colour of the background gradient in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BGCOLOR2","Gradient Colour 2");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BGCOLOR2_DESC","The second colour of the background gradient in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUTCOLOR","Button Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUTCOLOR_DESC","The colour of the buttons in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUTHCOLOR","Button Hover Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUTHCOLOR_DESC","Hover colour of buttons in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SLCOLOR0","Slider Colour 1");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SLCOLOR0_DESC","The first colour of the slider gradient in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SLCOLOR1","Slider Colour 2");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SLCOLOR1_DESC","The first colour of the slider gradient in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SLCOLORH","Slider Hover Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SLCOLORH_DESC","Hover colour of the bar in hexadecimal format without preceding # (eg 333333)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUFFMESS","Buffer Message");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUFFMESS_DESC","The buffering message. By default Buffering _n_, _n_ shown in percent.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUFFCOL","Buffer Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUFFCOL_DESC","The colour of the buffering message");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUFFBGCOL","Buffer Background");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BUFFBGCOL_DESC","The background colour of the buffering message");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWBUFFBG","Show Buffer Background");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWBUFFBG_DESC","0 to hide the background colour of the buffering message");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWBAR","Show Player Bar");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWBAR_DESC","Player bar display mode : autohide, always or never.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWLDBAR","Show Loading Bar");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWLDBAR_DESC","Loading bar display mode : autohide, always or never.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWFS","Show Fullscreen");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWFS_DESC","1 to show fullscreen button (requires Flash Player 9.0.16.60 or newer)");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWMOUSE","Show Mouse");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_SHOWMOUSE_DESC","Display of the mouse cursor : always, autohide, never.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_OCDEST","OnClick");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_OCDEST_DESC","The destination URL when clicking on the video. By default playpause, meaning that the video is played/paused on click. To remove events, set to none.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_OCTARGET","OnClick Target");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_OCTARGET_DESC","The target of the URL when clicking on the video. By default _self. To open a new window set to _blank.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_ODCDEST","OnDoubleClick");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_ODCDEST_DESC","Action on double click: none, fullscreen, playpause, or the URL to open.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_ODCTARGET","OnDoubleClick Target");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_ODCTARGET_DESC","The target of the URL when double clicking on the video. By default _self. To open a new window set to _blank.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_TIMEOUT","Player Timeout");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_TIMEOUT_DESC","The timeout in milliseconds before the player hides (when autohide mode is set). By default set to 1500.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_VIDBG","Empty Video Background");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_VIDBG_DESC","Background colour of the flash, when no video is shown.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_INIVOL","Initial Volume");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_INIVOL_DESC","The initial volume, between 0 and 200.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BARALPHA","Player Transparency");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAY_BARALPHA_DESC","The transparency of the player bar, between 0 and 100.");
DEFINE("_ADMIN_HWDVIDS_SETT_ALWAYS","Always");
DEFINE("_ADMIN_HWDVIDS_SETT_AUTOHIDE","Autohide");
DEFINE("_ADMIN_HWDVIDS_SETT_NEVER","Never");
DEFINE("_ADMIN_HWDVIDS_SETT_TBLANK","_blank");
DEFINE("_ADMIN_HWDVIDS_SETT_TPARENT","_parent");
DEFINE("_ADMIN_HWDVIDS_SETT_TSELF","_self");
DEFINE("_ADMIN_HWDVIDS_SETT_TTOP","_top");
DEFINE("_ADMIN_HWDVIDS_SETT_CAPTCHA","Captcha Security Image");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLECAPTCHA","Disable Captcha?");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLECAPTCHA_DESC","Disable the captcha security image so no human verification is required.");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLENAVTABS","Disable Main Navigation Tabs");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEVIDTAB","Disable Video Tab");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEVIDTAB_DESC","Disable the video tab so this link does not appear at the top of the page");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLECATTAB","Disable Category Tab");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLECATTAB_DESC","Disable the category tab so this link does not appear at the top of the page");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEGRPTAB","Disable Group Tab");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEGRPTAB_DESC","Disable the group tab so this link does not appear at the top of the page");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEULDTAB","Disable Upload Tab");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEULDTAB_DESC","Disable the upload tab so this link does not appear at the top of the page");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWCOPYRIGHT","Credit Link");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWCREDIT","Show 'powered by' notice?");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWCREDIT_DESC","We always appreciate return links but if you are a subscriber you can switch this off!");
DEFINE("_ADMIN_HWDVIDS_SETT_VIDEDIT","Video Edit and Removal Feature");
DEFINE("_ADMIN_HWDVIDS_SETT_ALLOWEDIT","Allow Video Edit?");
DEFINE("_ADMIN_HWDVIDS_SETT_ALLOWEDIT_DESC","Allow users to edit their own videos through the website frontend");
DEFINE("_ADMIN_HWDVIDS_SETT_ALLOWDEL","Allow Video Deletion?");
DEFINE("_ADMIN_HWDVIDS_SETT_ALLOWDEL_DESC","Allow users to delete their own videos through the website frontend");
DEFINE("_ADMIN_HWDVIDS_SETT_RECONFLV","Reconvert FLV/MP4 Videos?");
DEFINE("_ADMIN_HWDVIDS_SETT_RECONFLV_DESC","Do you want to re-convert flv videos using your conversions settings or just copy them directly in to hwdVideoShare?");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAYERSEL","Select your video player");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVPLAYERSEL_DESC","Select a video player from the list below to use on your website. This is the player that will be used to play videos users have uploaded to your website from their local computers.");
DEFINE("_ADMIN_HWDVIDS_SETT_UPLDMETH","Upload Method");
DEFINE("_ADMIN_HWDVIDS_SETT_UPLDMETH_DESC","Select the upload method you would like to use to process video file uploads. The Advanced (PERL) Method might require manual configuration of Perl Scripts.");
DEFINE("_ADMIN_HWDVIDS_SETT_UPLDMETH_ADVPERL","The <a href=\"http://documentation.hwdmediashare.co.uk/wiki/Advanced_Perl_Upload_Method\" target=\"_blank\"><b>Advanced (PERL) Method</b></a> uses <a href=\"http://uber-uploader.sourceforge.net/\" target=\"_blank\">Uber Uploader</a> to process the uploads via Perl Scripts. This method features a real time progress bar, and large upload limits. You may need to manually configure the Perl Scripts to function correctly on your server.");
DEFINE("_ADMIN_HWDVIDS_SETT_UPLDMETH_ADVFLASH","The <a href=\"http://documentation.hwdmediashare.co.uk/wiki/Advanced_Flash_Upload_Method\" target=\"_blank\"><b>Advanced (FLASH) Method</b></a> uses <a href=\"http://www.pixeline.be/experiments/jqUploader/\" target=\"_blank\">jqUploader</a> to process the uploads via a flash-based file upload widget, allowing the display of a progress bar and percentage.");
DEFINE("_ADMIN_HWDVIDS_SETT_ADVPERL","Advanced (PERL)");
DEFINE("_ADMIN_HWDVIDS_SETT_ADVFLASH","Advanced (FLASH)");
DEFINE("_ADMIN_HWDVIDS_SETT_ADVAJAX","Advanced (AJAX)");
DEFINE("_ADMIN_HWDVIDS_SETT_BASPHP","Basic (PHP)");
DEFINE("_ADMIN_HWDVIDS_SETT_INTEGRATIONSGJ","Group Jive Integration");
DEFINE("_ADMIN_HWDVIDS_SETT_VISITSITE","[Visit Website]");
DEFINE("_ADMIN_HWDVIDS_SETT_ALLOWFT","Allowed Filetypes");
DEFINE("_ADMIN_HWDVIDS_SETT_ALLOWFT_CHECK","Please select the file formats you wish to accept.");
DEFINE("_ADMIN_HWDVIDS_SETT_ALLOWFT_NOCHECK","You do not have the required third party software to convert video files. <b>You can only accept the flv video format</b>. If you do have the software installed, switch on this setting in the Setup tab.");
DEFINE("_ADMIN_HWDVIDS_SETT_MAXFS","Maximum Upload Filesize");
DEFINE("_ADMIN_HWDVIDS_SETT_MAXUPLD","Maximum Upload Size (MB)");
DEFINE("_ADMIN_HWDVIDS_SETT_MAXUPLD_DESC","Enter the maximum upload filesize you wish to accept. See below for some restrictions.");
DEFINE("_ADMIN_HWDVIDS_SETT_MAXUPLD_FLASH","Due to limitations in the flash player, the maximum allowed size for the Flash Uploader is 100 MB");
DEFINE("_ADMIN_HWDVIDS_SETT_MAXUPLD_FLASHLIM","Maximum filesize for flash player = 100 MB");
DEFINE("_ADMIN_HWDVIDS_SETT_RESTRICTFLASH","Flash Restrictions");
DEFINE("_ADMIN_HWDVIDS_SETT_PLAYERALIGN","Video Player Alignment");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVALIGN","Align Player");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVALIGN_DESC","Do you want to align the video player to the left, right or in the centre?");
DEFINE("_ADMIN_HWDVIDS_SETT_LEFT","Left");
DEFINE("_ADMIN_HWDVIDS_SETT_RIGHT","Right");
DEFINE("_ADMIN_HWDVIDS_SETT_CENTER","Centre");
DEFINE("_ADMIN_HWDVIDS_SETT_INFOALIGN","Align video information next to video?");
DEFINE("_ADMIN_HWDVIDS_SETT_INFOALIGN_DESC","If you choose to align the video player to the left or the right you can choose to put the video information next to it. This will maximise the use of space on your website. If you align the video player in the centre you will need to put the information below it.");
DEFINE("_ADMIN_HWDVIDS_SETT_SWITCHOFF","Switch Off");
DEFINE("_ADMIN_HWDVIDS_SETT_DEFAULTSO","Default Sharing Options");
DEFINE("_ADMIN_HWDVIDS_SETT_DSACCESS","Default Access Setting");
DEFINE("_ADMIN_HWDVIDS_SETT_DSACCESS_DESC","Set the default access setting for new videos");
DEFINE("_ADMIN_HWDVIDS_SETT_USACCESS","Can user change?");
DEFINE("_ADMIN_HWDVIDS_SETT_USACCESS_DESC","Can the user change this default value? If no, then option will not show during uploads");
DEFINE("_ADMIN_HWDVIDS_SETT_DSCOMMS","Default Comment Setting");
DEFINE("_ADMIN_HWDVIDS_SETT_DSCOMMS_DESC","Set the default comment setting for new videos");
DEFINE("_ADMIN_HWDVIDS_SETT_USCOMMS","Can user change?");
DEFINE("_ADMIN_HWDVIDS_SETT_USCOMMS_DESC","Can the user change this default value? If no, then option will not show during uploads");
DEFINE("_ADMIN_HWDVIDS_SETT_DSEMBED","Default Embed Setting");
DEFINE("_ADMIN_HWDVIDS_SETT_DSEMBED_DESC","Set the default embedding setting for new videos");
DEFINE("_ADMIN_HWDVIDS_SETT_USEMBED","Can user change?");
DEFINE("_ADMIN_HWDVIDS_SETT_USEMBED_DESC","Can the user change this default value? If no, then option will not show during uploads");
DEFINE("_ADMIN_HWDVIDS_SETT_DSRATE","Default Rating Setting");
DEFINE("_ADMIN_HWDVIDS_SETT_DSRATE_DESC","Set the default rating setting for new videos");
DEFINE("_ADMIN_HWDVIDS_SETT_USRATE","Can user change?");
DEFINE("_ADMIN_HWDVIDS_SETT_USRATE_DESC","Can the user change this default value? If no, then option will not show during uploads");
DEFINE("_ADMIN_HWDVIDS_SETT_MAINACCESS","Main Group Access Details");
DEFINE("_ADMIN_HWDVIDS_SETT_MAINCOMACCESS","Main Component Access");
DEFINE("_ADMIN_HWDVIDS_SETT_MAINCOMACCESS_DESC","Set the groups who can access the hwdVideoShare component");
DEFINE("_ADMIN_HWDVIDS_SETT_INCLUDECHILD_DESC","Do you want to include all child groups from the above selection?");
DEFINE("_ADMIN_HWDVIDS_SETT_GROUPACCESS","Access to Groups Feature");
DEFINE("_ADMIN_HWDVIDS_SETT_GROUPACCESS_DESC","Set the Joomla groups who can access the hwdVideoShare group features");
DEFINE("_ADMIN_HWDVIDS_SETT_CBAVAWIDTH","Avatar Image Width");
DEFINE("_ADMIN_HWDVIDS_SETT_VIDTHUMB","Video Thumbnails");
DEFINE("_ADMIN_HWDVIDS_SETT_THUMBW","Width of thumbnails");
DEFINE("_ADMIN_HWDVIDS_SETT_HEAD1","Path to third party tools");
DEFINE("_ADMIN_HWDVIDS_SETT_CNVNSET","Standard Definition Conversion Settings");
DEFINE("_ADMIN_HWDVIDS_SETT_CNVNSET_WARNING","WARNING: Increasing the quality of the output video can put significant load on your server during the conversion. It will also increase the filesize of the output video.");
DEFINE("_ADMIN_HWDVIDS_SETT_CNVTPROG","Preferred Converter");
DEFINE("_ADMIN_HWDVIDS_SETT_CNVTPROG_DESC","Select your preferred video conversion utility.");
DEFINE("_ADMIN_HWDVIDS_SETT_CUSTOMENCODEOPT","Custom Encoding Options");
DEFINE("_ADMIN_HWDVIDS_SETT_CUSTOMENCODEOPT_DESC","Add your own custom encoding options. These values will be directly added to the end of the encoding command. (<b>ADVANCED USERS ONLY</b>)");
DEFINE("_ADMIN_HWDVIDS_SETT_WMVFIX","Apply A/V Sync Fix");
DEFINE("_ADMIN_HWDVIDS_SETT_WMVFIX_DESC","If your audio/visual is not syncronised apply this fix. The output files will be larger.");
DEFINE("_ADMIN_HWDVIDS_SETT_THUMBFAIL","Abort Conversion if Thumb Fails?");
DEFINE("_ADMIN_HWDVIDS_SETT_THUMBFAIL_DESC","Do you want to abort a video conversion if the creation of the thumbnail image fails so that you can retry later?");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLESEARCHBAR","Disable Search Bar");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLESEARCHBAR_DESC","Disable the search bar");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEUSERBAR","Disable User Bar");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEUSERBAR_DESC","Disable the user bar that displays links to the user's videos, favourite videos and groups (Will only display when a user has logged in)");
DEFINE("_ADMIN_HWDVIDS_SETT_TRUNCATE","Title &amp; Description Truncation");
DEFINE("_ADMIN_HWDVIDS_SETT_TRUNTITLE","Truncate titles");
DEFINE("_ADMIN_HWDVIDS_SETT_TRUNTITLE_DESC","You can choose to truncate the titles of videos and groups on the main list pages to this number of characters");
DEFINE("_ADMIN_HWDVIDS_SETT_TRUNVDESC","Truncate video descriptions");
DEFINE("_ADMIN_HWDVIDS_SETT_TRUNVDESC_DESC","You can choose to truncate the video descriptions of videos and groups on the main list pages to this number of characters");
DEFINE("_ADMIN_HWDVIDS_SETT_TRUNCDESC","Truncate category descriptions");
DEFINE("_ADMIN_HWDVIDS_SETT_TRUNCDESC_DESC","You can choose to truncate the category descriptions of videos and groups on the main list pages to this number of characters");
DEFINE("_ADMIN_HWDVIDS_SETT_TRUNGDESC","Truncate group descriptions");
DEFINE("_ADMIN_HWDVIDS_SETT_TRUNGDESC_DESC","You can choose to truncate the group descriptions of videos and groups on the main list pages to this number of characters");
DEFINE("_ADMIN_HWDVIDS_SETT_SOCBM","Social Bookmark Links");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWRATE","Show rating?");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWRATE_DESC","Show video rating on video list pages?");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWVIEWS","Show views?");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWVIEWS_DESC","Show number of views on video list pages?");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWDURATION","Show duration?");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWDURATION_DESC","Show duration on video list pages?");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWUPLDER","Show uploader?");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWUPLDER_DESC","Show who uploaded video on video list pages?");
DEFINE("_ADMIN_HWDVIDS_SETT_AUTOCON","Automatic Conversions");
DEFINE("_ADMIN_HWDVIDS_SETT_COMMSYS","Commenting System Integration");
DEFINE("_ADMIN_HWDVIDS_SETT_COMMCOM","Commenting Component");
DEFINE("_ADMIN_HWDVIDS_SETT_COMMCOM_DESC","Which Joomla commenting component do you wish to use with hwdVideoShare");
DEFINE("_ADMIN_HWDVIDS_SETT_INTGJ","Integrate with GroupJive?");
DEFINE("_ADMIN_HWDVIDS_SETT_INTGJ_DESC","Integration is under development");
DEFINE("_ADMIN_HWDVIDS_SETT_INFORMUPLDRESTRICT","Inform User of Max Upload Size and Allowed Filetypes");
DEFINE("_ADMIN_HWDVIDS_SETT_INFORMUPLDTYPE","Inform User of Upload Criteria");
DEFINE("_ADMIN_HWDVIDS_SETT_INFORMUPLDTYPE_DESC","This will display the maximum filesize and allowed video formats on the upload page.");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1","Advert next to video player");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWAD1","Show Advert");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWAD1_DESC","Do you want to show an advert directly next to the main video player?");
DEFINE("_ADMIN_HWDVIDS_SETT_ADSENSE","AdSense Advert");
DEFINE("_ADMIN_HWDVIDS_SETT_CUSTOM","Custom Advert");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1CUSTOM","Custom Advert Code");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1CUSTOM_DESC","Add the code for your custom advert if you do not want to us AdSense");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADCLIENT","Publisher ID");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADCLIENT_DESC","Please type your Publisher ID provided by Google AdSense. It is an alphanumerical string like pub-123456789876543.");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADCHANNEL","Channel number");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADCHANNEL_DESC","Type the channel number that you may have set in Google AdSense. It is a numerical string like 54656789 and NOT any text string that you can choose.");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADTYPE","Ad Type");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADTYPE_DESC","Choose the ad types you would like to display on your page. If you are choosing Image Ads only option, please use only these sizes: 728X90 - Leaderboard, 468X60 - Banner, 300X250 - Medium Rectangle, 160X600 - Wide Skyscraper and 120X600 - Skyscraper");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADUIF","Corner Styles");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADUIF_DESC","Optionally, choose from one of the pre-designed corner styles.");
DEFINE("_ADMIN_HWDVIDS_SETT_ADS_TANDI","Text and image (default)");
DEFINE("_ADMIN_HWDVIDS_SETT_ADS_TEXT","Text only");
DEFINE("_ADMIN_HWDVIDS_SETT_ADS_IMAGE","Image only");
DEFINE("_ADMIN_HWDVIDS_SETT_ADS_SQUARE","Square corners");
DEFINE("_ADMIN_HWDVIDS_SETT_ADS_SR","Slightly rounded corners");
DEFINE("_ADMIN_HWDVIDS_SETT_ADS_VR","Very rounded corners");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1LAYOUT","Ad layout");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1LAYOUT_DESC","Choose the ad format and size that you would like to display on your page.");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM1","468 x 60 Banner");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM2","234 x 60 Half Banner");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM3","120 x 600 Skyscraper");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM4","160 x 600 Wide Skyscraper");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM5","120 x 240 Vertical Banner");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM6","336 x 280 Large Rectangle");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM7","300 x 250 Medium rectangle");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM8","250 x 250 Square");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM9","200 x 200 Small Square");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM10","180 x 150 Small Rectangle");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM11","125 x 125 Button");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM12","728 x 90 Leaderboard");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM13","728 x 15 Adlink 4 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM14","468 x 15 Adlink 4 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM15","120 x 90 Adlink 4 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM16","160 x 90 Adlink 4 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM17","180 x 90 Adlink 4 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM18","200 x 90 Adlink 4 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM19","728 x 15 Adlink 5 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM20","468 x 15 Adlink 5 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM21","120 x 90 Adlink 5 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM22","160 x 90 Adlink 5 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM23","180 x 90 Adlink 5 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1FORM24","200 x 90 Adlink 5 links");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADBORDER","Border Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADBORDER_DESC","Border colour, in hex, without #");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADBG","Background Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADBG_DESC","Background colour, in hex, without #");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADLINK","Link Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADLINK_DESC","Link colour, in hex, without #");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADTEXT","Text Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADTEXT_DESC","Text colour, in hex, without #");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADURL","URL Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1ADURL_DESC","URL colour, in hex, without #");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1UIF","Corner Styles");
DEFINE("_ADMIN_HWDVIDS_SETT_AD1UIF_DESC","Optionally, choose from one of the pre-designed corner styles.");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVAUTOSTART","Auto Start?");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVAUTOSTART_DESC","Automatically start the video player when the page is loaded?");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVOVERSTRETCH","Over Stretch?");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVOVERSTRETCH_DESC","This will stretch the video to fit the size of the video player, ignoring the original dimensions of the video file. [CHECK BELOW FOR USAGE INSTRUCTIONS]");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVLOGO","Player Logo");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVLOGO_DESC","Set this to an image that can be put as a watermark logo on the video player. Transparent PNG files give the best results. [CHECK BELOW FOR USAGE INSTRUCTIONS]");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVVOLUME","Starting Volume");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVVOLUME_DESC","The starting volume of the player. This can later be changed by the user. [CHECK BELOW FOR USAGE INSTRUCTIONS]");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVBG","Background Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVBG_DESC","Background colour of the player controls, in HEX format. [CHECK BELOW FOR USAGE INSTRUCTIONS]");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVFG","Foreground Colour");
DEFINE("_ADMIN_HWDVIDS_SETT_FLVFG_DESC","Foreground colour of the player controls, in HEX format. [CHECK BELOW FOR USAGE INSTRUCTIONS]");
DEFINE("_ADMIN_HWDVIDS_SETT_FPORDER","Order of Frontpage Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_FPORDER_DESC","Select the order of the video lists on the component frontpage");
DEFINE("_ADMIN_HWDVIDS_SETT_FPORDER_RECENT","Most Recent");
DEFINE("_ADMIN_HWDVIDS_SETT_FPORDER_POPULAR","Most Popular");
DEFINE("_ADMIN_HWDVIDS_SETT_FPORDER_VIEWED","Most Viewed");
DEFINE("_ADMIN_HWDVIDS_SETT_PERLSCRIPTSETUP","How to Setup the Advanced Perl Upload Method");
DEFINE("_ADMIN_HWDVIDS_SETT_VERIFYTHUMBSEXIST","Verify Third Party Thumbnails Exist?");
DEFINE("_ADMIN_HWDVIDS_SETT_VERIFYTHUMBSEXIST_DESC","hwdVideoShare tries to verify the existence of third party thumbnail images (From YouTube and GoogleVideo etc) with the <b>get_headers</b> php function. If the thumbnail image does not exist the default thumbnail image will be shown instead. Additionally, if the <b>get_headers</b> function is not available then the default thumbnail image will always be shown, regardless of whether the real image exists or not. Set this value to No if you want to overwrite this option and always use the third party thumbnail without verifying it's existence with the <b>get_headers</b> function.");
DEFINE("_ADMIN_HWDVIDS_SETT_RATESYS","Video rating method");
DEFINE("_ADMIN_HWDVIDS_SETT_FAVSYS","Add to favourite method");
DEFINE("_ADMIN_HWDVIDS_SETT_FAVSYS_DESC","Select the method (POST or AJAX) that users will use to add videos to their favourites. The AJAX method will not interrupt video playback.");
DEFINE("_ADMIN_HWDVIDS_SETT_REPORTSYS","Report video method");
DEFINE("_ADMIN_HWDVIDS_SETT_REPORTSYS_DESC","Select the method (POST or AJAX) that users will use to report inappropriate videos. The AJAX method will not interrupt video playback.");
DEFINE("_ADMIN_HWDVIDS_SETT_A2GSYS","Add to group method");
DEFINE("_ADMIN_HWDVIDS_SETT_A2GSYS_DESC","Select the method (POST or AJAX) that users will use to add videos to groups. The AJAX method will not interrupt video playback.");
DEFINE("_ADMIN_HWDVIDS_SETT_BKP_1","hwdVideoShare has just tested your server and thinks you will be able to successfully use this feature!");
DEFINE("_ADMIN_HWDVIDS_SETT_BKP_0","hwdVideoShare has just tested your server and unfortunately this feature will not work!");
DEFINE("_ADMIN_HWDVIDS_SETT_VPINTMET","Video Page Interaction Methods");
DEFINE("_ADMIN_HWDVIDS_SETT_VPINFOOT","Video Page Information Options");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEUSRTABS","Disable User Navigation Bar");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEYVLINK","Disable <b>Your Videos</b> Link");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEYVLINK_DESC","Disable this link on the user navigation bar so it does not appear");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEYFLINK","Disable <b>Your Favourites</b> Link");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEYFLINK_DESC","Disable this link on the user navigation bar so it does not appear");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEYGLINK","Disable <b>Your Groups</b> Link");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEYGLINK_DESC","Disable this link on the user navigation bar so it does not appear");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEYMLINK","Disable <b>Your Group Memberships</b> Link");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEYMLINK_DESC","Disable this link on the user navigation bar so it does not appear");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLECGLINK","Disable <b>Create New Group</b> Link");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLECGLINK_DESC","Disable this link on the user navigation bar so it does not appear");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWRAT_DESC","Allow users to use this feature when they are viewing a video");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWATF","Enable <b>Add To Favourites</b> Feature");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWATF_DESC","Allow users to use this feature when they are viewing a video");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWRPB","Enable <b>Report Media</b> Feature");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWRPB_DESC","Allow users to use this feature when they are viewing a video");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWCOM","Enable <b>Commenting</b> Feature");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWCOM_DESC","Allow users to use this feature when they are viewing a video");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWVUR","Show <b>Video URL</b> Link");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWVUR_DESC","Allow users to use this feature when they are viewing a video");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWVEB","Show <b>Video Embed</b> Code");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWVEB_DESC","Allow users to use this feature when they are viewing a video");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWDSC","Show Video <b>Description</b>");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWDSC_DESC","Allow users to see this text when they are viewing a video");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWTAG","Show Video <b>Tags</b>");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWTAG_DESC","Allow users to see this text when they are viewing a video");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWSBK","Show <b>Social Bookmarks</b>");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWSBK_DESC","Allow users to see these links when they are viewing a video");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWA2G","Show <b>Add to Group</b> Feature");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWA2G_DESC","Allow users to add videos to groups");
DEFINE("_ADMIN_HWDVIDS_SETT_PLAYERACCESS","Access to Video Player");
DEFINE("_ADMIN_HWDVIDS_SETT_PLAYERACCESS_DESC","Set the Joomla groups who can access the video player and watch videos");
DEFINE("_ADMIN_HWDVIDS_SETT_LANGUAGE_DESC","Choose the hwdVideoShare language plugin. To add more languages, install language plugins through the plugin manager.");
DEFINE("_ADMIN_HWDVIDS_SETT_VPLAYER","Select Video Player");
DEFINE("_ADMIN_HWDVIDS_SETT_VPLAYER_DESC","Choose the hwdVideoShare video player plugin. To add more player, install player plugins through the plugin manager.");
DEFINE("_ADMIN_HWDVIDS_SETT_MAXUPLDWARN1","<h3>Warning :: Maximum Upload Filesize is generating a warning</h3><p>Your Maximum Upload Filesize is too large, hwdVideoShare will automatically reduce this setting to the maximum value allowed by your server.</p><p style=\"font-size:80%\">Your current Upload method is restricted by the <i>upload_max_filesize</i> setting in your php.ini file.</p>");
DEFINE("_ADMIN_HWDVIDS_SETT_MAXUPLDWARN2","<h3>Warning :: Maximum Upload Filesize is generating a warning</h3><p>Your Maximum Upload Filesize is too large, hwdVideoShare will automatically reduce this setting to the maximum value allowed by your server.</p><p style=\"font-size:80%\">Your current Upload method is restricted by the <i>post_max_size</i> setting in your php.ini file.</p>");
DEFINE("_ADMIN_HWDVIDS_SETT_UPLDWARN1","<h3>Warning :: Your upload method is generating a warning</h3><p>hwdVideoShare can not verify that the Advanced Perl Upload method is setup correctly.</p>");
DEFINE("_ADMIN_HWDVIDS_SETT_UPLDWARN2","<h3>Error :: Your upload method is generating an error</h3><p>hwdVideoShare does not think that the Advanced Perl Upload method is setup correctly.</p>");
DEFINE("_ADMIN_HWDVIDS_SETT_ACCESSSET","Access Settings");
DEFINE("_ADMIN_HWDVIDS_SETT_ACCESSMETHOD","Access Verification Method");
DEFINE("_ADMIN_HWDVIDS_SETT_ACCESSMETHOD_DESC","Do you wish to specify access by <b>Access Groups</b> or <b>Access Levels</b>?");
DEFINE("_ADMIN_HWDVIDS_SETT_ACCESSGRP","Access Groups");
DEFINE("_ADMIN_HWDVIDS_SETT_ACCESSLEV","Access Levels");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPL","XML Shareable Playlists (XSPL)");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPL_DESC","XML Shareable Playlist Format (XSPF), pronounced spiff, is an XML-based playlist format for digital media, sponsored by the Xiph.Org Foundation. Lucas Gonze of Yahoo.com/Webjay.org originated the format in 2004. XSPF is a data format for sharing the kind of playlist that can be played on a personal computer or portable device. In the same way that any user on any computer can open any web page, XSPF is intended to provide portability for playlists.");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPLCACHE_TODAY","Playlist Cache [Today]");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPLCACHE_TODAY_DESC","The time to cache XML playlists for today's results. The playlists will be re-generated after this amount of time.");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPLCACHE_TW","Playlist Cache [This Week]");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPLCACHE_TW_DESC","The time to cache XML playlists for this weeks results. The playlists will be re-generated after this amount of time.");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPLCACHE_TM","Playlist Cache [This Month]");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPLCACHE_TM_DESC","The time to cache XML playlists for this months results. The playlists will be re-generated after this amount of time.");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPLCACHE_AT","Playlist Cache [All Time]");
DEFINE("_ADMIN_HWDVIDS_SETT_XMLPLCACHE_AT_DESC","The time to cache XML playlists for all results. The playlists will be re-generated after this amount of time.");
DEFINE("_ADMIN_HWDVIDS_SETT_CUSTOMXML","Custom Playlist");
DEFINE("_ADMIN_HWDVIDS_SETT_CUSTOMXML_DESC","Create your own custom playlists by listing comma separated video ids, for example: 34, 543, 48, 97, 234");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHENO","Don't Cache");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHE60","60 Secs (Every Minute)");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHE300","300 Secs (Every 5 Minutes)");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHE600","600 Secs (Every 10 Minutes)");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHE1800","1800 Secs (Every 30 Minutes)");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHE3600","3600 Secs (Every Hour)");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHE18000","18000 Secs (Every 5 Hours)");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHE36000","36000 Secs (Every 10 Hours)");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHE86400","86000 Secs (Daily)");
DEFINE("_ADMIN_HWDVIDS_SETT_CACHE604800","604800 Secs (Weekly)");
DEFINE("_ADMIN_HWDVIDS_SETT_TPMETHOD","Third Party Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_TPFUNC","Primary Data Transfer Method");
DEFINE("_ADMIN_HWDVIDS_SETT_TPFUNC_DESC","Choose between the <a href=\"http://php.net/curl\" target=\"_blank\">CURL</a> function and the <a href=\"http://php.net/file_get_contents\" target=\"_blank\">file_get_contents</a> function when transferring data from third party websites. (CURL is more secure.)");
DEFINE("_ADMIN_HWDVIDS_SETT_PTHL","Play in Local Player");
DEFINE("_ADMIN_HWDVIDS_SETT_PTHL_DESC","Where possible, play the third party video in the local video player (instead of the third party's own video player).");
DEFINE("_ADMIN_HWDVIDS_SETT_AAVIDS","Auto-approve Uploaded Videos?");
DEFINE("_ADMIN_HWDVIDS_SETT_SAUPLD","Automatically Convert Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_SAUPLD_DESC","Do you want to send uploaded video files directly to the converter for processing immediately after the upload is complete?<br />This will send the video file to be converted as a background process (<b>> /dev/null &</b>). If you select Yes and your videos do not automatically get converted, <b>your server might not support this feature</b>.");
DEFINE("_ADMIN_HWDVIDS_SETT_UPLDMETH_BASPHP","The <a href=\"http://documentation.hwdmediashare.co.uk/wiki/Basic_PHP_Upload_Method\" target=\"_blank\"><b>Basic (PHP) Method</b></a> uses only php to process the video file uploads. It should not require any manual configuration to function correctly, but will generally have smaller upload limits.");
DEFINE("_ADMIN_HWDVIDS_SETT_RESTRICTPHP","PHP Upload Restrictions");
DEFINE("_ADMIN_HWDVIDS_SETT_MAXUPLD_PHP","Your server has the following restrictions on the maximum video filesize.");
DEFINE("_ADMIN_HWDVIDS_SETT_NO_PARAMS","No Parameters.");
DEFINE("_ADMIN_HWDVIDS_SETT_FRONTPAGE","Frontpage Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWWN","Show Videos Being Watched Now");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWWN_DESC","A list of videos currently being watched will be available on the video gallery frontpage");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWMV","Show Most Viewed Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWMV_DESC","A list of most viewed videos will be available on the video gallery frontpage");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWMF","Show Most Favoured Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWMF_DESC","A list of most favoured videos will be available on the video gallery frontpage");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWMP","Show Most Popular Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWMP_DESC","A list of most popular videos will be available on the video gallery frontpage");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWULR","Show <b>More From This User</b>");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWULR_DESC","Allow users to see who uploaded this video and more videos from the user");
DEFINE("_ADMIN_HWDVIDS_SETT_NOTIFYR","Notify after new report?");
DEFINE("_ADMIN_HWDVIDS_SETT_NOTIFYR_DESC","Send a notification email when a user reports media as inappropriate");
DEFINE("_ADMIN_HWDVIDS_SETT_CONVERTSWF","Playback of SWF Videos");
DEFINE("_ADMIN_HWDVIDS_SETT_SWFSA","Play swf videos independently?");
DEFINE("_ADMIN_HWDVIDS_SETT_SWFSA_DESC","Choose if you want swf files to be embedded independently as a stand-alone object or played in your video player.");
DEFINE("_ADMIN_HWDVIDS_SETT_PATHSL","Path to Shared Libraries");
DEFINE("_ADMIN_HWDVIDS_SETT_PATHSL_DESC","Temporarily substitute a different library for the hwdVideoShare conversion executions.");
DEFINE("_ADMIN_HWDVIDS_SETT_JACLINT","JACL Plus Integration");
DEFINE("_ADMIN_HWDVIDS_SETT_INTJACL","Integrate with JACL Plus?");
DEFINE("_ADMIN_HWDVIDS_SETT_INTJACL_DESC","Integration with JACL Plus will enable you to manage access to hwdVideoShare via Access Levels.");
DEFINE("_ADMIN_HWDVIDS_SETT_FTODAY","From Today");
DEFINE("_ADMIN_HWDVIDS_SETT_FTW","From This Week");
DEFINE("_ADMIN_HWDVIDS_SETT_FTM","From This Month");
DEFINE("_ADMIN_HWDVIDS_SETT_FAT","From All Time");
DEFINE("_ADMIN_HWDVIDS_SETT_TPWIDTH","Width of third party video player");
DEFINE("_ADMIN_HWDVIDS_SETT_TPWIDTH_DESC","If hwdVideoShare embeds a video player from an external website you can set the width here. The height will be automatically calculated for the specific website format. For example, if you play a video that is widescreen, it will display as widescreen.");
DEFINE("_ADMIN_HWDVIDS_SETT_RATESYS_DESC","Select the method (POST or AJAX) that users will use to rate videos. The AJAX method will not interrupt video playback.");
DEFINE("_ADMIN_HWDVIDS_SETT_INTEGRATIONSCB","Community Integration");
DEFINE("_ADMIN_HWDVIDS_SETT_INTCB","Integrate with Community software?");
DEFINE("_ADMIN_HWDVIDS_SETT_INTCB_DESC","Integration will allow users to pass to community profiles");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWCBAVA","Show Community Avatar?");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWCBAVA_DESC","Display avatar images in hwdVideoShare?");
DEFINE("_ADMIN_HWDVIDS_SETT_CBITEMID","Community Software Itemid");
DEFINE("_ADMIN_HWDVIDS_SETT_CBITEMID_DESC","To make sure hwdVideoShare links to the correct profile page add the Itemid for your main Community software. See our documentation for more help.");
DEFINE("_ADMIN_HWDVIDS_SETT_THUMBW_DESC","Set the width of your video thumbnails. Default value is 120.");
DEFINE("_ADMIN_HWDVIDS_SETT_VAR","Video Aspect Ratios");
DEFINE("_ADMIN_HWDVIDS_SETT_CVAR","Calculate Video Aspect Ratio?");
DEFINE("_ADMIN_HWDVIDS_SETT_CVAR_DESC","Attempt to automatically calulate aspect ratio of video");
DEFINE("_ADMIN_HWDVIDS_SETT_VFR","Fallback Ratio");
DEFINE("_ADMIN_HWDVIDS_SETT_VFR_DESC","Ratio to use if aspect can not be calculated");
DEFINE("_ADMIN_HWDVIDS_SETT_VTC","Video Thumbnail Configuration");
DEFINE("_ADMIN_HWDVIDS_SETT_TAR","Thumbnail Aspect Ratio");
DEFINE("_ADMIN_HWDVIDS_SETT_TAR_DESC","Ratio to use for thumbnail images");
DEFINE("_ADMIN_HWDVIDS_SETT_UDT","Use Dynamic Thumbnails");
DEFINE("_ADMIN_HWDVIDS_SETT_UDT_DESC","Use dynmamic thumbnails which scroll through video snaphosts");
DEFINE("_ADMIN_HWDVIDS_SETT_OFORMATS","Other allowed formats");
DEFINE("_ADMIN_HWDVIDS_SETT_OFORMATS_DESC","Add support for extra formats in hwdVideoShare");
DEFINE("_ADMIN_HWDVIDS_SETT_NBWNO","Number of <b>being watched</b> videos");
DEFINE("_ADMIN_HWDVIDS_SETT_NBWNO_DESC","Set the number of Now Being Watched videos to display");
DEFINE("_ADMIN_HWDVIDS_SETT_SOFTINS","Video Conversion Software Installed?");
DEFINE("_ADMIN_HWDVIDS_SETT_SOFTINS_DESC","Does your server have the server requirements installed? This software is required to process uploaded video files.");
DEFINE("_ADMIN_HWDVIDS_SETT_ORDERING","Default List Ordering");
DEFINE("_ADMIN_HWDVIDS_SETT_CORDERING","Category Ordering");
DEFINE("_ADMIN_HWDVIDS_SETT_CORDERING_DESC","Orders the actual category list");
DEFINE("_ADMIN_HWDVIDS_SETT_CVORDERING","Category Video Ordering");
DEFINE("_ADMIN_HWDVIDS_SETT_CVORDERING_DESC","Orders videos when viewing videos in categories");
DEFINE("_ADMIN_HWDVIDS_SETT_CUSTORDERING_DESC","Allow users to order lists as they like");
DEFINE("_ADMIN_HWDVIDS_SETT_UPLOADACCESS","Access to Local Upload Feature");
DEFINE("_ADMIN_HWDVIDS_SETT_UPLOADACCESS_DESC","Set the groups who can upload local videos to the hwdVideoShare component");
DEFINE("_ADMIN_HWDVIDS_SETT_TPUPLOADACCESS","Access to Third Party Upload Feature");
DEFINE("_ADMIN_HWDVIDS_SETT_TPUPLOADACCESS_DESC","Set the groups who can upload third party videos to the hwdVideoShare component");
DEFINE("_ADMIN_HWDVIDS_SETT_DNLDACCESS","Access to Video Downloads");
DEFINE("_ADMIN_HWDVIDS_SETT_DNLDACCESS_DESC","Set the groups who can download videos from the hwdVideoShare component");
DEFINE("_ADMIN_HWDVIDS_SETT_BVIIC","Hide Restricted Videos in Lists");
DEFINE("_ADMIN_HWDVIDS_SETT_BVIIC_DESC","Hide videos in lists which the user does not have permission to access.");
DEFINE("_ADMIN_HWDVIDS_SETT_CUSTORDERING","Users Choose Ordering?");
DEFINE("_ADMIN_HWDVIDS_SETT_LOGCONVERT_DESC","Create a log file of video conversions (Stored at JoomlaRoot/media/hwdVideoShare_VideoConversionLog.dat)");
DEFINE("_ADMIN_HWDVIDS_VBITRATE","Video Bitrate");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_DESC","Set the video bitrate in kbit/s (Default 200 kb/s)");
DEFINE("_ADMIN_HWDVIDS_ABITRATE","Audio Bitrate");
DEFINE("_ADMIN_HWDVIDS_ABITRATE_DESC","Set the audio bitrate in kbit/s (Default 64 kbit/s)");
DEFINE("_ADMIN_HWDVIDS_ASR","Audio Sample Rate");
DEFINE("_ADMIN_HWDVIDS_ASR_DESC","Set the audio samplerate in Hz (Default 22050 Hz)");
DEFINE("_ADMIN_HWDVIDS_FSIZE","Video Frame Size");
DEFINE("_ADMIN_HWDVIDS_FSIZE_DESC","Set frame size.");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VP","16 kbit/s - Videophone Quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VC2","200 kbit/s - Video-conferencing system quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VC3","300 kbit/s - Video-conferencing system quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VC4","400 kbit/s - Video-conferencing system quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VC5","500 kbit/s - Video-conferencing system quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VC6","600 kbit/s - Video-conferencing system quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VC7","700 kbit/s - Video-conferencing system quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VC8","800 kbit/s - Video-conferencing system quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VC9","900 kbit/s - Video-conferencing system quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VC10","1000 kbit/s - Video-conferencing system quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VCD15","1500 kbit/s - VCD quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VCD20","2000 kbit/s - VCD quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VCD25","2500 kbit/s - VCD quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VCD30","3000 kbit/s - VCD quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VCD35","3500 kbit/s - VCD quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VCD40","4000 kbit/s - VCD quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VCD45","4500 kbit/s - VCD quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_VCD","1250 kbit/s - VCD quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_DVD","5000 kbit/s - DVD quality");
DEFINE("_ADMIN_HWDVIDS_VBITRATE_HDTV","15000 kbit/s - HDTV quality");
DEFINE("_ADMIN_HWDVIDS_ABITRATE_AM","32 kbit/s - AM quality");
DEFINE("_ADMIN_HWDVIDS_ABITRATE_DF","64 kbit/s - Default quality");
DEFINE("_ADMIN_HWDVIDS_ABITRATE_FM","96 kbit/s - FM quality");
DEFINE("_ADMIN_HWDVIDS_ABITRATE_ST","128 kbit/s - Standard Bitrate quality");
DEFINE("_ADMIN_HWDVIDS_ABITRATE_DBA","192 kbit/s - DAB (Digital Audio Broadcasting) quality");
DEFINE("_ADMIN_HWDVIDS_ABITRATE_CD","224 kbit/s - CD quality");
DEFINE("_ADMIN_HWDVIDS_ASR_TELE","8,000 Hz - Telephone and encrypted walkie-talkie");
DEFINE("_ADMIN_HWDVIDS_ASR_QURT","11,025 Hz - One quarter the sampling rate of audio CDs; used for lower-quality PCM");
DEFINE("_ADMIN_HWDVIDS_ASR_HALF","22,050 Hz - One half the sampling rate of audio CDs; used for lower-quality PCM");
DEFINE("_ADMIN_HWDVIDS_ASR_MINIDV","32,000 Hz - MiniDV digital video camcorder");
DEFINE("_ADMIN_HWDVIDS_ASR_NTSC","44,056 Hz - PCM adaptor using NTSC video tapes");
DEFINE("_ADMIN_HWDVIDS_ASR_CD","44,100 Hz - Audio CD");
DEFINE("_ADMIN_HWDVIDS_ASR_PCM","47,250 Hz - World's first commercial PCM");
DEFINE("_ADMIN_HWDVIDS_ASR_DTV","48,000 Hz - Digital sound used for miniDV and digital TV");
DEFINE("_ADMIN_HWDVIDS_ASR_AREC","50,000 Hz - First commercial digital audio recorders from 3M and Soundstream");
DEFINE("_ADMIN_HWDVIDS_FSIZE_DF","DEFAULT 160x128 [4:3]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_QVGA","QVGA 320x240 [4:3]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_CGA","CGA 320x200 [8:5]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_VGA","VGA 640x480 [4:3]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_NTSC","NTSC 720x480 [3:2]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_PAL","PAL 768x576 [4:3]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_SVGA","SVGA 800x600 [4:3]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_WVGA1","WVGA 800x480 [5:3]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_WVGA2","WVGA 854x480 [16:9]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_WSVGA","WSVGA 1024x600");
DEFINE("_ADMIN_HWDVIDS_FSIZE_SXGA","SXGA 1280x1024 [5:4]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_HD720","HD720 1280x720 [16:9]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_WXGA1","WXGA 1280x768 [5:3]");
DEFINE("_ADMIN_HWDVIDS_FSIZE_WXGA2","WXGA 1280x800 [8:5]");
DEFINE("_ADMIN_HWDVIDS_SETT_CBAVAWIDTH_DESC","Width (in pixels) of avatar image. Using large size will pixalate image.");
DEFINE("_ADMIN_HWDVIDS_SETT_SOFTINS_YES","If yes, you will be able to use hwdVideoShare to the full potential of the software and accept uploads in all popular video formats.");
DEFINE("_ADMIN_HWDVIDS_SETT_SOFTINS_NO","If no, you will not be able to convert videos. hwdVideoShare will only accept uploads in the flv video format.");
DEFINE("_ADMIN_HWDVIDS_SETT_YES","Yes");
DEFINE("_ADMIN_HWDVIDS_SETT_NO","No");
DEFINE("_ADMIN_HWDVIDS_SETT_INCLUDECHILD","Include Child groups?");
DEFINE("_ADMIN_HWDVIDS_SELECT_TEMPLATE","Select Template");
DEFINE("_ADMIN_HWDVIDS_SELECT_LANGUAGE","Select Language");
DEFINE("_ADMIN_HWDVIDS_SELECT_PLAYER","Select Player");
DEFINE("_ADMIN_HWDVIDS_DEFAULT_TEMPLATE","Default Template");
DEFINE("_ADMIN_HWDVIDS_LANGUAGE_ENGLISH","English Language");
DEFINE("_ADMIN_HWDVIDS_LANGUAGE_JOOMFISH","Core Joomla Language");
DEFINE("_ADMIN_HWDVIDS_SETT_SHOWRAT","Enable <b>Rating Feature</b>");
DEFINE("_ADMIN_HWDVIDS_HIDEUPLDNA","Use Access Settings");



DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEPLTAB","Disable Playlist Tab");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLEPLTAB_DESC","Disable the playlist tab so this link does not appear at the top of the page");

DEFINE("_ADMIN_HWDVIDS_SETT_DISABLECHTAB","Disable Channel Tab");
DEFINE("_ADMIN_HWDVIDS_SETT_DISABLECHTAB_DESC","Disable the channel tab so this link does not appear at the top of the page");

DEFINE("_ADMIN_HWDVIDS_SETT_UPLDMETH_REMWARP","The <a href=\"http://documentation.hwdmediashare.co.uk/wiki/Remote_(WARP_HD)_Upload_Method\" target=\"_blank\"><b>Remote (WARP HD) Method</b></a> allows you to upload, convert and deliver videos from the remote WARP HD services.");
