{* 
//////
//    @version [ Nightly Build ]
//    @package hwdVideoShare
//    @copyright (C) 2007 - 2011 Highwood Design
//    @license http://creativecommons.org/licenses/by-nc-nd/3.0/
//////
*}

<div class="box">
<div class="listtitle"><a href="{$data->channel_link}">{$data->channel_name}</a> {$data->editchannel} {$data->deletechannel}</div>
<p>{$data->channel_description}</p>
<div style="clear:both;"></div>
</div>

