{* 
//////
//    @version [ Nightly Build ]
//    @package hwdVideoShare
//    @copyright (C) 2007 - 2011 Highwood Design
//    @license http://creativecommons.org/licenses/by-nc-nd/3.0/
//////
*}
 
{include file='admin_header.tpl'}
		
<table cellpadding="4" cellspacing="1" border="0" class="adminform">
  <tr>
    <td colspan="2">
      <div style="margin:5px;border:solid 1px #333;padding:5px;width:100%:">
        <h1>This video is queued for swf processing</h1>
        <p>More information will become available when the file has been processed.</p>
      </div>
    </td>
  </tr>
</table>

{include file='admin_footer.tpl'}
