{* 
//////
//    @version [ Nightly Build ]
//    @package hwdVideoShare
//    @copyright (C) 2007 - 2011 Highwood Design
//    @license http://creativecommons.org/licenses/by-nc-nd/3.0/
//////
*}

{$hidden_inputs}
</form>
<table width="100%"  border="0" cellspacing="0" cellpadding="0" class="adminform" style="margin:10px 0;">
    <tr>
        <td align="center"><center>{$backEndCopyright}</center></td>
    </tr>
</table>
