{* 
//////
//    @version [ Nightly Build ]
//    @package hwdVideoShare
//    @copyright (C) 2007 - 2011 Highwood Design
//    @license http://creativecommons.org/licenses/by-nc-nd/3.0/
//////
*}

<div class="standard">
  <h2>{$smarty.const._HWDVIDS_TITLE_NEWTHUMB}</h2>
  <table width="100%" cellpadding="0" cellspacing="0" border="0">
    <tr>
      <td width="150">{$smarty.const._HWDVIDS_DETAILS_NEWTHUMB}</td>
      <td><input type="file" name="thumbnail_file" value="" size="30"></td>
    </tr>
    <tr>
      <td width="150"></td>
      <td>{$smarty.const._HWDVIDS_DETAILS_NEWTHUMB_DESC}</td>
    </tr>
  </table>
</div>
