{* 
//////
//    @version [ Nightly Build ]
//    @package hwdVideoShare
//    @copyright 2008 Highwood Design
//    @license http://creativecommons.org/licenses/by-nc-nd/3.0/
//////
//    hwdVideoShare Template System:::This template system uses the Smarty Template Engine. 
//    For full documentation, including syntax usage please refer to http://www.smarty.net 
//    or our website at http://www.hwdmediashare.co.uk   
//////
*}

{include file='admin_header.tpl'}
		
<table cellpadding="4" cellspacing="1" border="0" class="adminform">
  <tr>
    <td colspan="2">
      <div style="margin:5px;border:solid 1px #333;padding:5px;width:100%:">
        <h1>This video is queued for a thumbnail image</h1>
        <p>More information will become available when the thumbnail image has been created successfully.</p>
      </div>
    </td>
  </tr>
</table>

{include file='admin_footer.tpl'}
