{* 
//////
//    @version [ Nightly Build ]
//    @package hwdVideoShare
//    @copyright (C) 2007 - 2011 Highwood Design
//    @license http://creativecommons.org/licenses/by-nc-nd/3.0/
//////
*}

<h2>{$smarty.const._HWDVIDS_HOME_01}</h2>

<ul>
    <li>{$smarty.const._HWDVIDS_HOME_02}</li>
    <li>{$smarty.const._HWDVIDS_HOME_03}</li>
    <li>{$smarty.const._HWDVIDS_HOME_04}</li>
    <li>{$smarty.const._HWDVIDS_HOME_05}</li>
</ul>
      
<h3>{$smarty.const._HWDVIDS_HOME_08}</h3>

<ul>
    <li><a href="http://documentation.hwdmediashare.co.uk/wiki/Server_Requirements_for_hwdVideoShare" target="_blank">http://documentation.hwdmediashare.co.uk/wiki/Server_Requirements_for_hwdVideoShare</a><//li>
</ul>

<h3>Recommended</h3>

<ul>
    <li><a href="http://documentation.hwdmediashare.co.uk/wiki/Server_Recommendations_for_hwdVideoShare" target="_blank">http://documentation.hwdmediashare.co.uk/wiki/Server_Recommendations_for_hwdVideoShare</a><//li>
</ul>

<h3>{$smarty.const._HWDVIDS_HOME_30}</h3>

<ul>
    <li><a href="http://forum.hwdmediashare.co.uk/" target="_blank">http://forum.hwdmediashare.co.uk/</a><//li>
    <li><a href="http://documentation.hwdmediashare.co.uk/wiki/Main_Page" target="_blank">http://documentation.hwdmediashare.co.uk/wiki/Main_Page</a><//li>
</ul>
  
<h2>{$smarty.const._HWDVIDS_HOME_26}</h2>

<p>{$smarty.const._HWDVIDS_HOME_27}</p>
<ul>
    <li><b>Silk Icons</b> @ <a href="http://famfamfam.com/lab/icons/silk/" target="_blank">http://famfamfam.com/lab/icons/silk/</a> [{$smarty.const._HWDVIDS_HOME_28}: Marc James, {$smarty.const._HWDVIDS_HOME_29} <a href="http://creativecommons.org/licenses/by/2.5/" target="_blank">Creative Commons Attribution 2.5 License</a>]</li>
    <li><b>Uber-Uploader</b> @ <a href="http://sourceforge.net/projects/uber-uploader/" target="_blank">http://sourceforge.net/projects/uber-uploader/</a> [{$smarty.const._HWDVIDS_HOME_28}: Peter Schmandra, {$smarty.const._HWDVIDS_HOME_29} <a href="http://www.mozilla.org/MPL/" target="_blank">Mozilla Public License Version 1.1</a>]</li>
    <li><b>PHP Captcha Security Images</b> @ <a href="http://www.white-hat-web-design.co.uk/articles/php-captcha.php" target="_blank">http://www.white-hat-web-design.co.uk/articles/php-captcha.php</a> [{$smarty.const._HWDVIDS_HOME_28}: Simon Jarvis, {$smarty.const._HWDVIDS_HOME_29} <a href="http://www.gnu.org/licenses/gpl.html" target="_blank">GNU/GPL License</a>]</li>
    <li><b>FLV Player</b> @ <a href="http://flv-player.net/" target="_blank">http://flv-player.net/</a> [{$smarty.const._HWDVIDS_HOME_28}: neolao (neolao@gmail.com), {$smarty.const._HWDVIDS_HOME_29} <a href="http://www.mozilla.org/MPL/" target="_blank">Mozilla Public License Version 1.1</a>]</li>
    <li><b>Nifty Corners</b> @ <a href="http://www.editsite.net/blog/rounded_corners.html" target="_blank">http://www.editsite.net/blog/rounded_corners.html</a> [{$smarty.const._HWDVIDS_HOME_28}: Ilkka Huotari, Released Free for personal and commercial use (open/closed source) but please give credit]</li>
    <li><b>jqUploader</b> @ <a href="http://www.pixeline.be/experiments/jqUploader/" target="_blank">http://www.pixeline.be/experiments/jqUploader/</a> [{$smarty.const._HWDVIDS_HOME_28}: Alexandre Plennevaux,  {$smarty.const._HWDVIDS_HOME_29} <a href="http://www.opensource.org/licenses/mit-license.php" target="_blank">MIT Licence</a>]</li>
    <li><b>Flow Player</b> @ <a href="http://flowplayer.org/" target="_blank">http://flowplayer.org/</a> [{$smarty.const._HWDVIDS_HOME_28}: Flowplayer.com, {$smarty.const._HWDVIDS_HOME_29} <a href="http://www.gnu.org/licenses/gpl.html" target="_blank">GPL License</a>]</li>
    <li><b>Masuga AJAX Rater</b> @ <a href="http://www.masugadesign.com/the-lab/scripts/unobtrusive-ajax-star-rating-bar/" target="_blank">http://www.masugadesign.com/the-lab/scripts/unobtrusive-ajax-star-rating-bar/</a> [{$smarty.const._HWDVIDS_HOME_28}: Ryan Masuga, {$smarty.const._HWDVIDS_HOME_29} <a href="http://creativecommons.org/licenses/by/3.0/" target="_blank">Creative Commons Attribution 3.0 License</a>]</li>
    <li><b>Starbox Rating Stars</b> @ <a href="http://www.nickstakenburg.com/projects/starbox/" target="_blank">http://www.nickstakenburg.com/projects/starbox/</a> [{$smarty.const._HWDVIDS_HOME_28}: Nick Stakenburg, {$smarty.const._HWDVIDS_HOME_29} <a href="http://www.opensource.org/licenses/mit-license.php" target="_blank">MIT Licence</a>]</li>
    <li><b>Open Source FLV</b> @ <a href="http://www.osflv.com/" target="_blank">http://www.osflv.com/</a> [{$smarty.const._HWDVIDS_HOME_28}: Trent Tompkins, {$smarty.const._HWDVIDS_HOME_29} <a href="http://www.gnu.org/licenses/gpl.html" target="_blank">GNU/GPL License</a>]</li>
    <li><b>JW FLV MEDIA PLAYER</b> @ <a href="http://www.jeroenwijering.com/?item=JW_FLV_Player" target="_blank">http://www.jeroenwijering.com/?item=JW_FLV_Player</a> [{$smarty.const._HWDVIDS_HOME_28}: Jeroen Wijering, {$smarty.const._HWDVIDS_HOME_29} <a href="http://creativecommons.org/licenses/by/2.5/" target="_blank">Creative Commons Attribution 2.5 License</a>]</li>
</ul>

