<?php
/**
 *    @version [ Nightly Build ]
 *    @package hwdVideoShare
 *    @copyright (C) 2007 - 2011 Highwood Design
 *    @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 ***
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
defined( '_JEXEC' ) or die( 'Direct Access to this location is not allowed.' );

global $langConversionArray;

$langConversionArray['af'] = "afrikaans";           //Afrikaans
$langConversionArray['ar-sa'] = "pure_arabic";      //Arabic (Saudi Arabia)
$langConversionArray['ar-eg'] = "pure_arabic";      //Arabic (Egypt)
$langConversionArray['ar-dz'] = "pure_arabic";      //Arabic (Algeria)
$langConversionArray['ar-tn'] = "pure_arabic";      //Arabic (Tunisia)
$langConversionArray['ar-ye'] = "pure_arabic";      //Arabic (Yemen)
$langConversionArray['ar-jo'] = "pure_arabic";      //Arabic (Jordan)
$langConversionArray['ar-kw'] = "pure_arabic";      //Arabic (Kuwait)
$langConversionArray['ar-bh'] = "pure_arabic";      //Arabic (Bahrain)
$langConversionArray['eu'] = "basque";              //Basque
$langConversionArray['be'] = "belarusian";          //Belarusian
$langConversionArray['zh-tw'] = "chinese";          //Chinese (Taiwan)
$langConversionArray['zh-hk'] = "chinese";          //Chinese (Hong Kong SAR)
$langConversionArray['hr'] = "croatian";            //Croatian
$langConversionArray['da'] = "danish";              //Danish
$langConversionArray['nl-be'] = "dutch";            //Dutch (Belgium)
$langConversionArray['en-us'] = "english";          //English (United States)
$langConversionArray['en-au'] = "english";          //English (Australia)
$langConversionArray['en-nz'] = "english";          //English (New Zealand)
$langConversionArray['en-za'] = "english";          //English (South Africa)
$langConversionArray['en'] = "english";             //English (Caribbean)
$langConversionArray['en-tt'] = "english";          //English (Trinidad)
$langConversionArray['fo'] = "faeroese";            //Faeroese
$langConversionArray['fi'] = "finnish";             //Finnish
$langConversionArray['fr-be'] = "french";           //French (Belgium)
$langConversionArray['fr-ch'] = "french";           //French (Switzerland)
$langConversionArray['gd'] = "gaelic";              //Gaelic (Scotland)
$langConversionArray['de'] = "german";              //German (Standard)
$langConversionArray['de-at'] = "german";           //German (Austria)
$langConversionArray['de-li'] = "german";           //German (Liechtenstein)
$langConversionArray['he'] = "hebrew";              //Hebrew
$langConversionArray['hu'] = "hungarian";           //Hungarian
$langConversionArray['id'] = "indonesian";          //Indonesian
$langConversionArray['it-ch'] = "italian";          //Italian (Switzerland)
$langConversionArray['ko'] = "korean";              //Korean
$langConversionArray['lv'] = "latvian";             //Latvian
$langConversionArray['mk'] = "macedonian";          //Macedonian (FYROM)
$langConversionArray['mt'] = "maltese";             //Maltese
$langConversionArray['no'] = "norwegian";           //Norwegian (Nynorsk)
$langConversionArray['pt-br'] = "portuguese";       //Portuguese (Brazil)
$langConversionArray['rm'] = "rhaeto-romanic";      //Rhaeto-Romanic
$langConversionArray['ro-mo'] = "romanian";         //Romanian (Republic of Moldova)
$langConversionArray['ru-mo'] = "russian";          //Russian (Republic of Moldova)
$langConversionArray['sr'] = "serbian";             //Serbian (Cyrillic)
$langConversionArray['sk'] = "slovak";              //Slovak
$langConversionArray['sb'] = "sorbian";             //Sorbian
$langConversionArray['es-mx'] = "spanish_informal"; //Spanish (Mexico)
$langConversionArray['es-cr'] = "spanish_informal"; //Spanish (Costa Rica)
$langConversionArray['es-do'] = "spanish_informal"; //Spanish (Dominican Republic)
$langConversionArray['es-co'] = "spanish_informal"; //Spanish (Colombia)
$langConversionArray['es-ar'] = "spanish_informal"; //Spanish (Argentina)
$langConversionArray['es-cl'] = "spanish_informal"; //Spanish (Chile)
$langConversionArray['es-py'] = "spanish_informal"; //Spanish (Paraguay)
$langConversionArray['es-sv'] = "spanish_informal"; //Spanish (El Salvador)
$langConversionArray['es-ni'] = "spanish_informal"; //Spanish (Nicaragua)
$langConversionArray['sx'] = "sutu";                //Sutu
$langConversionArray['sv-fi'] = "swedish";          //Swedish (Finland)
$langConversionArray['ts'] = "tsonga";              //Tsonga
$langConversionArray['tr'] = "turkish";             //Turkish
$langConversionArray['ur'] = "urdu";                //Urdu
$langConversionArray['vi'] = "vietnamese";          //Vietnamese
$langConversionArray['ji'] = "yiddish";             //Yiddish
$langConversionArray['sq'] = "albanian";            //Albanian
$langConversionArray['ar-iq'] = "pure_arabic";      //Arabic (Iraq)
$langConversionArray['ar-ly'] = "pure_arabic";      //Arabic (Libya)
$langConversionArray['ar-ma'] = "pure_arabic";      //Arabic (Morocco)
$langConversionArray['ar-om'] = "pure_arabic";      //Arabic (Oman)
$langConversionArray['ar-sy'] = "pure_arabic";      //Arabic (Syria)
$langConversionArray['ar-lb'] = "pure_arabic";      //Arabic (Lebanon)
$langConversionArray['ar-ae'] = "pure_arabic";      //Arabic (U.A.E.)
$langConversionArray['ar-qa'] = "pure_arabic";      //Arabic (Qatar)
$langConversionArray['bg'] = "bulgarian";           //Bulgarian
$langConversionArray['ca'] = "catalan";             //Catalan
$langConversionArray['zh-cn'] = "chinese";          //Chinese (PRC)
$langConversionArray['zh-sg'] = "chinese";          //Chinese (Singapore)
$langConversionArray['cs'] = "czech";               //Czech
$langConversionArray['nl'] = "dutch";               //Dutch (Standard)
$langConversionArray['en'] = "english";             //English
$langConversionArray['en-gb'] = "english";          //English (United Kingdom)
$langConversionArray['en-ca'] = "english";          //English (Canada)
$langConversionArray['en-ie'] = "english";          //English (Ireland)
$langConversionArray['en-jm'] = "english";          //English (Jamaica)
$langConversionArray['en-bz'] = "english";          //English (Belize)
$langConversionArray['et'] = "estonian";            //Estonian
$langConversionArray['fa'] = "farsi";               //Farsi
$langConversionArray['fr'] = "french";              //French (Standard)
$langConversionArray['fr-ca'] = "french";           //French (Canada)
$langConversionArray['fr-lu'] = "french";           //French (Luxembourg)
$langConversionArray['ga'] = "irish";               //Irish
$langConversionArray['de-ch'] = "german";           //German (Switzerland)
$langConversionArray['de-lu'] = "german";           //German (Luxembourg)
$langConversionArray['el'] = "greek";               //Greek
$langConversionArray['hi'] = "hindi";               //Hindi
$langConversionArray['is'] = "icelandic";           //Icelandic
$langConversionArray['it'] = "italian";             //Italian (Standard)
$langConversionArray['ja'] = "japanese";            //Japanese
$langConversionArray['ko'] = "korean";              //Korean (Johab)
$langConversionArray['lt'] = "lithuanian";          //Lithuanian
$langConversionArray['ms'] = "malaysian";           //Malaysian
$langConversionArray['no'] = "norwegian";           //Norwegian (Bokmal)
$langConversionArray['pl'] = "polish";              //Polish
$langConversionArray['pt'] = "portuguese";          //Portuguese (Portugal)
$langConversionArray['ro'] = "romanian";            //Romanian
$langConversionArray['ru'] = "russian";             //Russian
$langConversionArray['sz'] = "sami";                //Sami (Lappish)
$langConversionArray['sr'] = "serbian";             //Serbian (Latin)
$langConversionArray['sl'] = "slovenian";           //Slovenian
$langConversionArray['es'] = "spanish_informal";    //Spanish (Spain)
$langConversionArray['es-gt'] = "spanish_informal"; //Spanish (Guatemala)
$langConversionArray['es-pa'] = "spanish_informal"; //Spanish (Panama)
$langConversionArray['es-ve'] = "spanish_informal"; //Spanish (Venezuela)
$langConversionArray['es-pe'] = "spanish_informal"; //Spanish (Peru)
$langConversionArray['es-ec'] = "spanish_informal"; //Spanish (Ecuador)
$langConversionArray['es-uy'] = "spanish_informal"; //Spanish (Uruguay)
$langConversionArray['es-bo'] = "spanish_informal"; //Spanish (Bolivia)
$langConversionArray['es-hn'] = "spanish_informal"; //Spanish (Honduras)
$langConversionArray['es-pr'] = "spanish_informal"; //Spanish (Puerto Rico)
$langConversionArray['sv'] = "swedish";             //Swedish
$langConversionArray['th'] = "thai";                //Thai
$langConversionArray['tn'] = "tswana";              //Tswana
$langConversionArray['uk'] = "ukrainian";           //Ukrainian
$langConversionArray['ve'] = "venda";               //Venda
$langConversionArray['xh'] = "xhosa";               //Xhosa
$langConversionArray['zu'] = "zulu";                //Zulu

$langConversionArray['cs-cz'] = "czech";            //Czech
$langConversionArray['de-de'] = "german";           //German
$langConversionArray['es-es'] = "spanish_informal"; //German
$langConversionArray['fr-fr'] = "french";           //French
$langConversionArray['it-it'] = "italian";          //Italian
$langConversionArray['ru-ru'] = "russian";          //Russian
$langConversionArray['nl-nl'] = "dutch";            //Dutch
$langConversionArray['uk-ua'] = "ukrainian";        //Ukrainian
$langConversionArray['el-gr'] = "greek";            //Greek
$langConversionArray['ca-es'] = "catalan";          //Catalan
$langConversionArray['ar-aa'] = "pure_arabic";      //Arabic
$langConversionArray['hy-am'] = "armenian";         //Armenian
$langConversionArray['ja-jp'] = "japanese";         //Japanese
$langConversionArray['ko-kr'] = "korean";           //Korean
$langConversionArray['zh-cn'] = "simplified_chinese";          //Chinese
$langConversionArray['zh-hk'] = "simplified_chinese";          //Chinese
$langConversionArray['zh-mo'] = "simplified_chinese";          //Chinese
$langConversionArray['zh-tw'] = "simplified_chinese";          //Chinese
$langConversionArray['zh-tw'] = "simplified_chinese";          //Chinese
$langConversionArray['pl-pl'] = "polish";           //Polish
$langConversionArray['da-dk'] = "danish";           //Danish

?>