/*
multiBox - for MooTools 1.2 stylesheet - - - - */
a.mb, a:link.mb, a:visited.mb, a:hover.mb, a:active.mb{
	/*outline:none;
	float:left;
	margin:0 15px 15px 0;
	padding:0;
	text-decoration:none;
	color:#666;*/
}

.mb img{
	display:block;
	border:none;
}

.mbClear{
	clear:both;
	width:100%;
	height:20px;
}

.mbHidden, .multiBoxDesc{
	display:none;
}


/*
Pop-up styles - - - - */
.MultiBoxContainer{
	background:#fff;
	position:absolute;
	border:15px solid #000;
	display:none;
	z-index:103;
	text-align:left;
}

.MultiBoxLoading{
	background:url(../../images/mb/loader.gif) center no-repeat;
}

.MultiBoxContent{
	position:relative;
	width:100%;
	height:100%;
}

.MultiBoxClose{
	background:url(../../images/mb/close.png) no-repeat;
	position:absolute;
	top:-24px;
	right:-24px;
	width:24px;
	height:24px;
	cursor:pointer;
}

.MultiBoxControlsContainer{
	overflow:hidden;
	height:0;
	position:relative;
}

.MultiBoxControls{
	background:#000;
	width:100%;
	position:relative;
	font-family:Verdana,Arial,Helvetica,sans-serif;
	color:#fff;
}

.MultiBoxDownload a, .MultiBoxDownload a:link, .MultiBoxDownload a:visited, .MultiBoxDownload a:hover, .MultiBoxDownload a:active{
	font-size:9px;
	color:#ccc;
	margin:5px 0 0 35px;
	display:block;
	text-decoration:none;
	text-transform:uppercase;
	text-align:right;
	outline:none;
}

.MultiBoxDownload a:hover{
	color:#fff;
}

.MultiBoxPrevious{
	background:url(../../images/mb/left.png) no-repeat;
	position:absolute;
	width:24px;
	height:24px;
	left:0;
	margin:5px 0 0 0;
	cursor:pointer;
}

.MultiBoxNext{
	background:url(../../images/mb/right.png) no-repeat;
	position:absolute;
	width:24px;
	height:24px;
	right:0;
	margin:5px 0 0 0;
	cursor:pointer;
}

.MultiBoxNextDisabled{
	background:url(../../images/mb/rightDisabled.png) no-repeat;
	cursor:default;
}

.MultiBoxPreviousDisabled{
	background:url(../../images/mb/leftDisabled.png) no-repeat;
	cursor:default;
}


/*
Bottom text - - - - */
.MultiBoxTitle{
	position:relative;
	margin:10px 0 0 35px;
	float:left;
	font-size:11px;
	font-weight:bold;
	text-align:left;
	display:inline;
}

.MultiBoxNumber{
	position:relative;
	width:90px;
	margin:10px 35px 0 0;
	float:right;
	font-size:11px;
	text-align:right;
	display:inline;
}

.MultiBoxDescription{
	clear:left;
	position:relative;
	margin:0 35px 0 35px;
	padding:5px 0 0 0;
	font-size:11px;
	text-align:left;
}


/*
Overlay icon - - - - */
.OverlayIcon{
	background:transparent url(../../images/mb/MagIcon.png) no-repeat;
	position:absolute;
	right:-5px;
	top:-5px;
	width:17px;
	height:17px;
}


/*
MooTools tips - - - - */
.mbTips{
	background:#fff;
	font-size:10px;
	color:#000;
	border:1px solid #3FB6E2;
	padding:2px;
}

.mbTips .tip-text{
	display:none;
}