<?php
/**
 *    @version [ Nightly Build ]
 *    @package hwdVideoShare
 *    @copyright (C) 2007 - 2011 Highwood Design
 *    @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 ***
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***
 *    New Language Definitions are located at bottom of file
 *    DEFINITIONS HAVE FORM
 *    ---------------------
 *    DEFINE("_HWDVIDS_NAV_VIDEOS","Videos"); // Videos
 *           \___________________/  \_____/      \____/
 *            |                 |    |    \_____  \   \_____________________
 *            | PHP LANGUAGE    |    | LANGUAGE \__ \    COPY OF ORIGINAL   |
 *            | DEFINTIONS      |    | TRANSLATION |  \  ENGLISH DEFINITION |
 *            |_________________|    |_____________|    \___________________|
 ***
 *    TRANSLATOR CREDITS CAN GO HERE::
 *    ORIGINAL ENGLISH FILE BY HIGHWOOD DESIGN
 **/
defined( '_JEXEC' ) or die( 'Direct Access to this location is not allowed.' );

//Frontend Navigation Headers

DEFINE("_HWDVIDS_NAV_VIDEOS","Videos");
DEFINE("_HWDVIDS_NAV_CATEGORIES","Categories");
DEFINE("_HWDVIDS_NAV_GROUPS","Groups");
DEFINE("_HWDVIDS_NAV_UPLOAD","Upload");
DEFINE("_HWDVIDS_NAV_YOURGROUPS","Your Groups");
DEFINE("_HWDVIDS_NAV_YOURMEMBERSHIPS","Your Group Membership");
DEFINE("_HWDVIDS_NAV_CREATEGROUP","Create New Group");
DEFINE("_HWDVIDS_NAV_YOURVIDS","Your Videos");
DEFINE("_HWDVIDS_NAV_YOURFAVS","Your Favourites");
DEFINE("_HWDVIDS_NAV_CREATEPL","Create New Playlist");
DEFINE("_HWDVIDS_NAV_YOURPL","Your Playlists");
DEFINE("_HWDVIDS_NAV_YOURCHANNEL","Your Channel");

//Frontend Search

DEFINE("_HWDVIDS_SEARCHBAR","Search...");

//Details

DEFINE("_HWDVIDS_DETAILS_PB","Powered by");
DEFINE("_HWDVIDS_DETAILS_VIEWVID","View Video");
DEFINE("_HWDVIDS_DETAILS_VIDTYPE","Upload method");
DEFINE("_HWDVIDS_DETAILS_DELETEVID","Delete Video");
DEFINE("_HWDVIDS_DETAILS_EDITVID","Edit Video");
DEFINE("_HWDVIDS_DETAILS_LEAVEG","Leave Group");
DEFINE("_HWDVIDS_DETAILS_JOING","Join Group");
DEFINE("_HWDVIDS_DETAILS_DELETEG","Delete Group");
DEFINE("_HWDVIDS_DETAILS_REPORTG","Report Group");
DEFINE("_HWDVIDS_DETAILS_EDITG","Edit Group");
DEFINE("_HWDVIDS_DETAILS_MEMBERSG","Group Members");
DEFINE("_HWDVIDS_DETAILS_ADDFAV","Add to favourites");
DEFINE("_HWDVIDS_DETAILS_REMFAV","Remove from favourites");
DEFINE("_HWDVIDS_DETAILS_A2G","Add to a group");
DEFINE("_HWDVIDS_DETAILS_FLAGVID","Report Video");
DEFINE("_HWDVIDS_DETAILS_FLAG","Report");
DEFINE("_HWDVIDS_DETAILS_NEWTHUMB","New Thumbnail");
DEFINE("_HWDVIDS_DETAILS_NEWTHUMB_DESC","You can upload a new image for your video. Uploads are limited to 2MB.");
DEFINE("_HWDVIDS_DETAILS_DELETE","[Delete]");
DEFINE("_HWDVIDS_DETAILS_EDIT","[Edit]");
DEFINE("_HWDVIDS_DETAILS_VIEWED","Viewed");
DEFINE("_HWDVIDS_DETAILS_TIMES","times");

//Title

DEFINE("_HWDVIDS_TITLE_FEATUREDVIDS","Featured Videos");
DEFINE("_HWDVIDS_TITLE_RECENTUPLOADS","Recent Uploads");
DEFINE("_HWDVIDS_TITLE_ORDERING","Order by...");
DEFINE("_HWDVIDS_TITLE_UPLDADDTP","Add a video from an external website");
DEFINE("_HWDVIDS_TITLE_SUPWEB","Supported Websites");
DEFINE("_HWDVIDS_TITLE_OPTIONS","Sharing Options");
DEFINE("_HWDVIDS_TITLE_UPLOAD","Upload Video (Step 1 of 2)");
DEFINE("_HWDVIDS_TITLE_UPLOAD2","Upload Video (Step 2 of 2)");
DEFINE("_HWDVIDS_TITLE_UPLOADTYPE","How do you want to add videos?");
DEFINE("_HWDVIDS_TITLE_VIDMATCHING","Videos matching");
DEFINE("_HWDVIDS_TITLE_GROUPMATCHING","Groups matching");
DEFINE("_HWDVIDS_TITLE_YOURVIDS","Your Uploaded Videos");
DEFINE("_HWDVIDS_TITLE_YOURFAVS","Your Favourite Videos");
DEFINE("_HWDVIDS_TITLE_YOURGROUPS","Your Groups");
DEFINE("_HWDVIDS_TITLE_YOURMEMBERSHIPS","Your Group Memberships");
DEFINE("_HWDVIDS_TITLE_CREATEGROUP","Create a Group");
DEFINE("_HWDVIDS_TITLE_VIDCOMMS","Video Comments");
DEFINE("_HWDVIDS_TITLE_GROUPCOMMS","Group Comments");
DEFINE("_HWDVIDS_TITLE_CATEGORYVIDS","Category Videos");
DEFINE("_HWDVIDS_TITLE_FEATUREDGROUPS","Featured Groups");
DEFINE("_HWDVIDS_TITLE_GROUPS","Groups");
DEFINE("_HWDVIDS_TITLE_UPLOADSUCCESS","Upload Successful");
DEFINE("_HWDVIDS_TITLE_EDITVID","Edit Video Details");
DEFINE("_HWDVIDS_TITLE_NEWTHUMB","Upload a New Thumbnail Image");
DEFINE("_HWDVIDS_TITLE_UPLDFAIL","Upload Failed");
DEFINE("_HWDVIDS_TITLE_UPLDYVID","Upload Your Video");
DEFINE("_HWDVIDS_TITLE_CHYVID","Choose a file to upload");
DEFINE("_HWDVIDS_TITLE_POPULARVIDEOS","Popular Videos");
DEFINE("_HWDVIDS_TITLE_MOSTVIEWEDVIDS","Most Viewed Videos");
DEFINE("_HWDVIDS_TITLE_NOACCESS","Access Denied!");
DEFINE("_HWDVIDS_TITLE_ERROR","Error");
DEFINE("_HWDVIDS_TITLE_AV2G","Add to Group");
DEFINE("_HWDVIDS_TITLE_GRPVIDS","Group Videos");
DEFINE("_HWDVIDS_TITLE_PENDINGVIDEOS","Videos Pending Approval");
DEFINE("_HWDVIDS_TITLE_GCF","Group Creation Failed");

//Alerts

DEFINE("_HWDVIDS_ALERT_ALREADYAV2G","This video has already been added to this group.");
DEFINE("_HWDVIDS_ALERT_SUCJOIN","You have joined the group");
DEFINE("_HWDVIDS_ALERT_LOG2LEAVEG","You need to login to leave groups");
DEFINE("_HWDVIDS_ALERT_SUCLEAVE","You have left the group");
DEFINE("_HWDVIDS_ALERT_SUCFLAGGED","The media has been reported and will be reviewed shortly.");
DEFINE("_HWDVIDS_ALERT_ALREADYFLAG","This media has already been reported by a user.");
DEFINE("_HWDVIDS_ALERT_NOPERM","You do not have permission to edit this video");
DEFINE("_HWDVIDS_ALERT_DUPLICATE","This video can not be added because it has already been added to the gallery.");
DEFINE("_HWDVIDS_ALERT_NOTITLE","Please enter a video title");
DEFINE("_HWDVIDS_ALERT_NODESC","Please enter a video description");
DEFINE("_HWDVIDS_ALERT_NOCAT","Please choose a video category");
DEFINE("_HWDVIDS_ALERT_NOTAG","Please enter some video tags");
DEFINE("_HWDVIDS_ALERT_NOSECURE","Please enter the security code as it appears in the blue box");
DEFINE("_HWDVIDS_ALERT_NOGNAME","Please enter a group name");
DEFINE("_HWDVIDS_ALERT_NOCOMMS","Please enter your comments");
DEFINE("_HWDVIDS_ALERT_NOGDESC","Please enter a group description");
DEFINE("_HWDVIDS_ALERT_ERRSC","You typed in the security code incorrectly! Please try again");
DEFINE("_HWDVIDS_ALERT_GROUPNOEXIST","This group is pending approval or has been removed from our system<br /><br />");
DEFINE("_HWDVIDS_ALERT_ALREADYVOTED","You have already voted for this video");
DEFINE("_HWDVIDS_ALERT_ALREADYFAV","You have already added this video to your favourites");
DEFINE("_HWDVIDS_ALERT_VOTEADDED","You have successfully voted");
DEFINE("_HWDVIDS_ALERT_FAVADDED","Video added to your favourites");
DEFINE("_HWDVIDS_ALERT_FAVREM","Video removed from your favourites");
DEFINE("_HWDVIDS_ALERT_LOG2RATE","You need to login to rate videos");
DEFINE("_HWDVIDS_ALERT_LOG2ADDF","You need to login to add videos to your favourites");
DEFINE("_HWDVIDS_ALERT_LOG2REMF","You need to login to remove videos from your favourites");
DEFINE("_HWDVIDS_ALERT_LOG2ADDG","You need to login to create groups");
DEFINE("_HWDVIDS_ALERT_LOG2REMG","You need to login to delete your groups");
DEFINE("_HWDVIDS_ALERT_LOG2FLAG","You need to login to report media");
DEFINE("_HWDVIDS_ALERT_LOG2COMM","You need to login to comment");
DEFINE("_HWDVIDS_ALERT_LOG2JOING","You need to login to join groups");
DEFINE("_HWDVIDS_ALERT_LOG2AV2G","You need to login to add videos to groups");
DEFINE("_HWDVIDS_ALERT_LOG2CYG","You need to login to see your groups");
DEFINE("_HWDVIDS_ALERT_LOG2CYM","You need to login to see your group memberships");
DEFINE("_HWDVIDS_ALERT_LOG2CYV","You need to login to see your videos");
DEFINE("_HWDVIDS_ALERT_LOG2CYF","You need to login to see your favourite videos");
DEFINE("_HWDVIDS_ALERT_SUCAV2G","The video has been added to the group.");
DEFINE("_HWDVIDS_ALERT_SUCAV2PL","The video has been added to the playlist.");
DEFINE("_HWDVIDS_ALERT_GREMOVED","Your group has been deleted");
DEFINE("_HWDVIDS_ALERT_GSAVED","Your group has been saved");
DEFINE("_HWDVIDS_ALERT_GPENDING","Your group has been saved and is pending approval from our website moderators");
DEFINE("_HWDVIDS_ALERT_VIDEDITSAVED","Your video details have been updated");
DEFINE("_HWDVIDS_ALERT_NOCNAME","You need to enter a category name");
DEFINE("_HWDVIDS_ALERT_NOUPLDMETH","The website administrator has disabled all available upload methods.");
DEFINE("_HWDVIDS_ALERT_REGISTERFORGRUP","You need to register and login to access groups.<br /><br />");
DEFINE("_HWDVIDS_ALERT_GRUP_NOT_AUTHORIZED","You are not authorised to access groups.<br /><br />");
DEFINE("_HWDVIDS_ALERT_NOUPLOAD","Your video could not be uploaded, please try again later.<br /><br />");
DEFINE("_HWDVIDS_ALERT_LOADRATE","Loading rating system");
DEFINE("_HWDVIDS_ALERT_INVALVOTE","Sorry, vote appears to be invalid.");
DEFINE("_HWDVIDS_ALERT_THANKSVOTER","Thanks for voting!");
DEFINE("_HWDVIDS_ALERT_MISSINGINFO","You did not fill out all the fields, please complete the form again. No information has been saved.");
DEFINE("_HWDVIDS_ALERT_REGISTERFORUPLD","You need to register and login to upload videos.");
DEFINE("_HWDVIDS_ALERT_UPLD_NOT_AUTHORIZED","You are not authorized to upload videos.");
DEFINE("_HWDVIDS_ALERT_REGISTERFORCAT","You need to register and login to view this category.");
DEFINE("_HWDVIDS_ALERT_CAT_NOT_AUTHORIZED","You are not authorized to view this category.");
DEFINE("_HWDVIDS_ALERT_REGISTERFORPLYR","You need to register and login to view this video.");
DEFINE("_HWDVIDS_ALERT_PLYR_NOT_AUTHORIZED","You are not authorized to view this video.");
DEFINE("_HWDVIDS_ALERT_ERRUP","There has been an error whilst uploading your video file. Please contact us if this problem continues.");
DEFINE("_HWDVIDS_ALERT_REGISTERFORACCESS","You need to register and login to access this page.");
DEFINE("_HWDVIDS_ALERT_NOT_AUTHORIZED","You are not authorised to view this page.");
DEFINE("_HWDVIDS_ALERT_REGISTERFORVCAT","You need to register and login to view this video. You do not have permissions to access this category.");
DEFINE("_HWDVIDS_ALERT_VCAT_NOT_AUTHORIZED","You are not authorized to view this video. You do not have permissions to access this category.");
DEFINE("_HWDVIDS_ALERT_REGISTERFORDNLD","You need to register and login to download this video.");
DEFINE("_HWDVIDS_ALERT_DNLD_NOT_AUTHORIZED","You are not authorized to download this video.");
DEFINE("_HWDVIDS_ALERT_CSAVED","Your channel has been setup correctly.");

//Meta

DEFINE("_HWDVIDS_META_DEFAULT","Videos");
DEFINE("_HWDVIDS_META_FP","Frontpage");
DEFINE("_HWDVIDS_META_SR","Search Results");
DEFINE("_HWDVIDS_META_UPLD","Upload Your Videos");
DEFINE("_HWDVIDS_META_UPLDSUC","Successfully Uploaded Your Video");
DEFINE("_HWDVIDS_META_ADDSUC","Successfully Added Your Video");
DEFINE("_HWDVIDS_META_CATS","Video Categories");
DEFINE("_HWDVIDS_META_GRPS","Video Groups");
DEFINE("_HWDVIDS_META_NGRPS","Create a new group");
DEFINE("_HWDVIDS_META_YVIDS","Your uploaded videos");
DEFINE("_HWDVIDS_META_YFAVS","Your favourite videos");
DEFINE("_HWDVIDS_META_FEATU","Featured videos");
DEFINE("_HWDVIDS_META_YGRPS","Your groups");
DEFINE("_HWDVIDS_META_YGRPM","Your group memberships");
DEFINE("_HWDVIDS_META_FEATG","Featured groups");
DEFINE("_HWDVIDS_META_EVIDS","Edit your video information");
DEFINE("_HWDVIDS_META_NPL","Create a new playlist");
DEFINE("_HWDVIDS_META_EPL","Edit your playlist information");

//Selects

DEFINE("_HWDVIDS_SELECT_ORDERING","Ordering");
DEFINE("_HWDVIDS_SELECT_UPLDDATE","Upload Date");
DEFINE("_HWDVIDS_SELECT_NAME","Name");
DEFINE("_HWDVIDS_SELECT_HITS","Hits");
DEFINE("_HWDVIDS_SELECT_RATING","Rating");
DEFINE("_HWDVIDS_SELECT_RANDOM","Random");
DEFINE("_HWDVIDS_SELECT_NOVIDS","Number of Videos");
DEFINE("_HWDVIDS_SELECT_NOSUBS","Number of Subcategories");
DEFINE("_HWDVIDS_SELECT_UPLDADDTP","Add a video from an external website");
DEFINE("_HWDVIDS_SELECT_UPLDMETH01","Upload a video from my computer");
DEFINE("_HWDVIDS_SELECT_PUBLIC","Public Access");
DEFINE("_HWDVIDS_SELECT_REG","Registered Users Only");
DEFINE("_HWDVIDS_SELECT_ALLOWCOMMS","Allow Comments");
DEFINE("_HWDVIDS_SELECT_DONTALLOWCOMMS","Don't Allow Comments");
DEFINE("_HWDVIDS_SELECT_ALLOWEMB","Allow Embedding");
DEFINE("_HWDVIDS_SELECT_DONTALLOWEMB","Don't Allow Embedding");
DEFINE("_HWDVIDS_SELECT_ALLOWRATE","Allow Ratings");
DEFINE("_HWDVIDS_SELECT_DONTALLOWRATE","Don't Allow Ratings");
DEFINE("_HWDVIDS_SELECT_REQUIREAPP","Require Approval");
DEFINE("_HWDVIDS_SELECT_DONTREQUIREAPP","Don't Require Approval");

//Email Notification

DEFINE("_HWDVIDS_MAIL_SUBJECT1","New video upload on ");
DEFINE("_HWDVIDS_MAIL_SUBJECT2","New group created on ");
DEFINE("_HWDVIDS_MAIL_SUBJECT3","New comment created on ");
DEFINE("_HWDVIDS_MAIL_SUBJECT4","Media has been reported on ");
DEFINE("_HWDVIDS_MAIL_BODY0","There has been a new video upload on ");
DEFINE("_HWDVIDS_MAIL_BODY1","The video is called ");
DEFINE("_HWDVIDS_MAIL_BODY2","If you need to approve this video please log into your administration section.");
DEFINE("_HWDVIDS_MAIL_BODY3","There has been a new group created on ");
DEFINE("_HWDVIDS_MAIL_BODY4","The group is called ");
DEFINE("_HWDVIDS_MAIL_BODY5","If you need to manually publish this group please log into your administration section.");
DEFINE("_HWDVIDS_MAIL_BODY6","There has been a new comment written on ");
DEFINE("_HWDVIDS_MAIL_BODY7","Comment: ");
DEFINE("_HWDVIDS_MAIL_BODY8","If you need to manually publish this comment please log into your administration section.");
DEFINE("_HWDVIDS_MAIL_BODY9","Somebody has reported media as inappropriate on ");
DEFINE("_HWDVIDS_MAIL_BODY10","To watch the video please visit the following page:");
DEFINE("_HWDVIDS_MAIL_BODY11","If you need to edit or delete the media please log into your administration section.");
DEFINE("_HWDVIDS_MAIL_BODY12","To view the group please visit the following page:");
//Information

DEFINE("_HWDVIDS_INFO_GUEST","Guest");
DEFINE("_HWDVIDS_INFO_NRV","No Recent Videos");
DEFINE("_HWDVIDS_INFO_CHOOSECAT","Choose a category");
DEFINE("_HWDVIDS_INFO_NOCATS","There are no available categories");
DEFINE("_HWDVIDS_INFO_CONFIRMFRONTEDIT","Are you sure you want to edit this item?");
DEFINE("_HWDVIDS_INFO_CONFIRMFRONTDEL","Are you sure you want to delete this item?");
DEFINE("_HWDVIDS_INFO_NOPLUGIN","Sorry! This video can no longer be played on this website.");
DEFINE("_HWDVIDS_INFO_VIEWS","Views");
DEFINE("_HWDVIDS_INFO_CATEGORY","Category");
DEFINE("_HWDVIDS_INFO_MOREFEATUREDV","More Featured Videos");
DEFINE("_HWDVIDS_INFO_MOREFEATUREDG","More Featured Groups");
DEFINE("_HWDVIDS_INFO_VIDEOS","videos");
DEFINE("_HWDVIDS_INFO_SUBCATS","subcategories");
DEFINE("_HWDVIDS_INFO_TAGS","Tags are keywords used to explain your videos and should be comma separated. (holiday, beach, Spain, etc)");
DEFINE("_HWDVIDS_INFO_REQUIREDFIELDS","indicates required field");
DEFINE("_HWDVIDS_INFO_NMV","No matching videos");
DEFINE("_HWDVIDS_INFO_NMG","No matching groups");
DEFINE("_HWDVIDS_INFO_TOTMEM","Total Members");
DEFINE("_HWDVIDS_INFO_TOTVID","Total Videos");
DEFINE("_HWDVIDS_INFO_AUTOA2G","Join this group");
DEFINE("_HWDVIDS_INFO_NOINS_JCOMMENTS","jComments is not installed.");
DEFINE("_HWDVIDS_INFO_NOG","No Groups");
DEFINE("_HWDVIDS_INFO_CREATEDBY","Created By");
DEFINE("_HWDVIDS_INFO_NGV","This group has no videos");
DEFINE("_HWDVIDS_INFO_NFV","You do not have any favourite videos");
DEFINE("_HWDVIDS_INFO_NFEATV","There are no featured videos");
DEFINE("_HWDVIDS_INFO_NUV","You have not uploaded any videos");
DEFINE("_HWDVIDS_INFO_RATED","Rating: ");
DEFINE("_HWDVIDS_INFO_VIDEMBEDCODE","Embed Code");
DEFINE("_HWDVIDS_INFO_UPLDANOTHER","Upload another?");
DEFINE("_HWDVIDS_INFO_SUCUPLD","Successfully Uploaded");
DEFINE("_HWDVIDS_INFO_VIDEOWAIT1","Your video is queued for conversion and will appear on our website once this is complete.");
DEFINE("_HWDVIDS_INFO_VIDEOWAIT2","Your video is now waiting approval from our website moderators. Your video will appear once it has been reviewed and accepted.");
DEFINE("_HWDVIDS_INFO_VIDEOWAIT3","Your video has been added.");
DEFINE("_HWDVIDS_INFO_VIDEOWAIT4","Your video is now waiting approval from our website moderators.");
DEFINE("_HWDVIDS_INFO_LIMUPLD","Your video upload is limited to");
DEFINE("_HWDVIDS_INFO_ALLUPLD","You may upload videos with these formats:");
DEFINE("_HWDVIDS_INFO_M_VOTE","Vote");
DEFINE("_HWDVIDS_INFO_M_VOTES","Votes");
DEFINE("_HWDVIDS_INFO_M_CURR","Currently ");
DEFINE("_HWDVIDS_INFO_M_CAST","cast");
DEFINE("_HWDVIDS_INFO_M_TI","This is");
DEFINE("_HWDVIDS_INFO_NOTDEVELOPED","This feature will become available in the next release");
DEFINE("_HWDVIDS_INFO_NFEATG","There are no featured groups");
DEFINE("_HWDVIDS_INFO_NCV","There are no videos in this category");
DEFINE("_HWDVIDS_INFO_NVTD","No videos to display");
DEFINE("_HWDVIDS_INFO_NEWCODE","New Code?");
DEFINE("_HWDVIDS_INFO_TPTITLEFAIL","The video's title could not be found");
DEFINE("_HWDVIDS_INFO_TPDESCFAIL","The video's description could not be found.");
DEFINE("_HWDVIDS_INFO_TPKWFAIL","The video's keywords could not be found");
DEFINE("_HWDVIDS_INFO_NOINS_JOMCOMMENTS","JomComments Mambot is not installed.");
DEFINE("_HWDVIDS_INFO_ENABLEJAVA","Please enable Java Script in your browser or use a different browser to view this video. You might also need to <a href=\"http://www.adobe.com/shockwave/download/download.cgi?P1_Prod_Version=ShockwaveFlash\" target=\"_blank\">update your flash player</a>.");
DEFINE("_HWDVIDS_INFO_VTYPENOTSUPPORT","This video is no longer supported by this website");
DEFINE("_HWDVIDS_INFO_CONT","Continue ...");
DEFINE("_HWDVIDS_INFO_VIDURL","Video URL");
DEFINE("_HWDVIDS_INFO_EMBEDDISABLED","Embedding disabled");
DEFINE("_HWDVIDS_INFO_PROCESSING","Processing");
DEFINE("_HWDVIDS_INFO_PROCESSINGWAIT","Uploading... Please be patient whilst your video is uploaded.");
DEFINE("_HWDVIDS_INFO_CURRENTRATE","Current rating.");
DEFINE("_HWDVIDS_INFO_TPDRFAIL","The video's duration could not be found");
DEFINE("_HWDVIDS_INFO_FROM","From");
DEFINE("_HWDVIDS_INFO_NYG","You do not have any groups");
DEFINE("_HWDVIDS_INFO_NYGM","You do not have any group memberships");
DEFINE("_HWDVIDS_INFO_TPPROCESSFAIL","The video code you entered could not be processed! Your video has not been added.<br /><br />");

//Button

DEFINE("_HWDVIDS_BUTTON_SAVE","Save");
DEFINE("_HWDVIDS_BUTTON_UPDT","Update");
DEFINE("_HWDVIDS_BUTTON_CANX","Cancel");
DEFINE("_HWDVIDS_BUTTON_UPLOAD","Upload");
DEFINE("_HWDVIDS_BUTTON_CONTINUE","Continue...");
DEFINE("_HWDVIDS_BUTTON_RATE","Rate");
DEFINE("_HWDVIDS_BUTTON_ADD","Add");
DEFINE("_HWDVIDS_BUTTON_SAVEGROUP","Save Group");
DEFINE("_HWDVIDS_BUTTON_RESET","Reset");
DEFINE("_HWDVIDS_BUTTON_GO","Go");
DEFINE("_HWDVIDS_BUTTON_SEND","Send");
DEFINE("_HWDVIDS_BUTTON_SAVECHANNEL","Save Channel");
DEFINE("_HWDVIDS_BUTTON_VIEW","View");
DEFINE("_HWDVIDS_BUTTON_SAVEPL","Save Playlist");
DEFINE("_HWDVIDS_BUTTON_ADSEARCH","Advanced Search");

//Ajax

DEFINE("_HWDVIDS_AJAX_LOG2RATE","Login to rate");
DEFINE("_HWDVIDS_AJAX_RATEADDED","Rating added");
DEFINE("_HWDVIDS_AJAX_ALREADYRATE","You've already rated");
DEFINE("_HWDVIDS_AJAX_BBROKE","Your browser broke!");
DEFINE("_HWDVIDS_AJAX_THANKVOTE","Thanks for voting");
DEFINE("_HWDVIDS_AJAX_ALREADYFAV","Already a favourite");
DEFINE("_HWDVIDS_AJAX_ADDEDFAV","Added to favourites");
DEFINE("_HWDVIDS_AJAX_REMFAV","Removed from favourites");
DEFINE("_HWDVIDS_AJAX_LOG2FAV1","Login to add");
DEFINE("_HWDVIDS_AJAX_LOG2FAV2","Login to remove");
DEFINE("_HWDVIDS_AJAX_LOG2REPORT","Login to report");
DEFINE("_HWDVIDS_AJAX_ALREADYREPORT","Already reported");
DEFINE("_HWDVIDS_AJAX_VIDREPORT","Video reported");
DEFINE("_HWDVIDS_AJAX_LOG2ADD2G","Login to add");

//Upload Errors

DEFINE("_HWDVIDS_PHPUPLD_ERR00","The file could not be uploaded. The data in the form probably exceeds the post_max_size directive in php.ini. ");
DEFINE("_HWDVIDS_PHPUPLD_ERR01","The file is bigger than the PHP installation allows. The uploaded file exceeds the upload_max_filesize directive in php.ini.");
DEFINE("_HWDVIDS_PHPUPLD_ERR02","The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.");
DEFINE("_HWDVIDS_PHPUPLD_ERR03","The uploaded file was only partially uploaded. ");
DEFINE("_HWDVIDS_PHPUPLD_ERR04","No file was uploaded. ");
DEFINE("_HWDVIDS_PHPUPLD_ERR05","Unknown Error");
DEFINE("_HWDVIDS_PHPUPLD_ERR06","Missing a temporary folder. Introduced in PHP 4.3.10 and PHP 5.0.3.");
DEFINE("_HWDVIDS_PHPUPLD_ERR07","Failed to write file to disk.");
DEFINE("_HWDVIDS_PHPUPLD_ERR08","File upload stopped by extension.");
DEFINE("_HWDVIDS_UPLD_FORMERR01","We did not find a video title. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_FORMERR02","We did not find a video description. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_FORMERR03","We did not find a video category. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_FORMERR04","We did not find any video tags. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_FORMERR05","We did not find a video privacy setting. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_FORMERR06","We did not find a video comments option. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_FORMERR07","We did not find a video embedding option. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_FORMERR08","We did not find a video rating option. Please go back and complete the form.");
DEFINE("_HWDVIDS_ERROR_UPLDERR01","Your video upload failed. This could be for one of the following reasons:<ul><li>The uploaded file is too big, and exceeds the <b>upload_max_filesize</b> directive in php.ini.</li><li>The uploaded file went missing after the upload.</li><li>The file already exists on the server.</li></ul>");
DEFINE("_HWDVIDS_ERROR_UPLDERR02","The upload can not be processed because the file is too big. The size has been restricted by the website team to");
DEFINE("_HWDVIDS_ERROR_UPLDERR03","The upload can not be processed because it contains illegal characters.");
DEFINE("_HWDVIDS_ERROR_UPLDERR04","The upload can not be processed because you are not allowed to upload files in this format. It must be a valid filetype.");
DEFINE("_HWDVIDS_ERROR_UPLDERR05","The upload can not be processed because the file already exists on our server. Please try again later.");
DEFINE("_HWDVIDS_ERROR_UPLDERR06","The upload can not be processed because the file could not be saved to the server.");
DEFINE("_HWDVIDS_ERROR_UPLDERR07","The form was not complete. You need to complete all required sections.");
DEFINE("_HWDVIDS_ERROR_UPLDERR08","The upload failed. ERROR CODE 001.");
DEFINE("_HWDVIDS_ERROR_UPLDERR09","The upload failed. ERROR CODE 002.");
DEFINE("_HWDVIDS_ERROR_UPLDERR10","The upload failed. ERROR CODE 003.");
DEFINE("_HWDVIDS_ERROR_UPLDERR11","Your video could not be added. It is not from a supported website.");
DEFINE("_HWDVIDS_UPLD_GFORMERR01","We did not find a group title. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_GFORMERR02","We did not find a group privacy setting. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_GFORMERR03","We did not find a group comments option. Please go back and complete the form.");
DEFINE("_HWDVIDS_UPLD_GFORMERR04","We did not find a group description. Please go back and complete the form.");

//General

DEFINE("_HWDVIDS_MP_SAGO","seconds ago");
DEFINE("_HWDVIDS_MP_MAGO","minutes ago");
DEFINE("_HWDVIDS_MP_HAGO","hours ago");
DEFINE("_HWDVIDS_MP_DAGO","days ago");
DEFINE("_HWDVIDS_TEXT_NONE","None");
DEFINE("_HWDVIDS_ALT_RATED","Rated");
DEFINE("_HWDVIDS_WMIP_01","The website administrator needs to install the ");
DEFINE("_HWDVIDS_WMIP_02"," plugin.");
DEFINE("_HWDVIDS_MVTD","Most Viewed Today");
DEFINE("_HWDVIDS_MVTW","Most Viewed This Week");
DEFINE("_HWDVIDS_MVTM","Most Viewed This Month");
DEFINE("_HWDVIDS_MVAT","Most Viewed");
DEFINE("_HWDVIDS_MFTD","Most Favoured Today");
DEFINE("_HWDVIDS_MFTW","Most Favoured This Week");
DEFINE("_HWDVIDS_MFTM","Most Favoured This Month");
DEFINE("_HWDVIDS_MFAT","Most Favoured");
DEFINE("_HWDVIDS_MPTD","Most Popular Today");
DEFINE("_HWDVIDS_MPTW","Most Popular This Week");
DEFINE("_HWDVIDS_MPTM","Most Popular This Month");
DEFINE("_HWDVIDS_MPAT","Most Popular");
DEFINE("_HWDVIDS_BWN","Being Watched Now");
DEFINE("_HWDVIDS_RELATED","Related");
DEFINE("_HWDVIDS_UNKNOWN","Unknown");
DEFINE("_HWDVIDS_RECENT","Recent");
DEFINE("_HWDVIDS_FEATURED_VIDEOS","Featured Videos");
DEFINE("_HWDVIDS_TITLE","Title");
DEFINE("_HWDVIDS_LENGTH","Duration");
DEFINE("_HWDVIDS_RATING","Rating");
DEFINE("_HWDVIDS_DATEUPLD","Date Uploaded");
DEFINE("_HWDVIDS_DESC","Description");
DEFINE("_HWDVIDS_ACCESS","Access");
DEFINE("_HWDVIDS_ACOMMENTS","Allow Comments");
DEFINE("_HWDVIDS_AEMBEDDING","Allow Embedding");
DEFINE("_HWDVIDS_ARATINGS","Allow Rating");
DEFINE("_HWDVIDS_SHARE","Share");
DEFINE("_HWDVIDS_INFO","Info");
DEFINE("_HWDVIDS_VURL","Video URL");
DEFINE("_HWDVIDS_MORECATVIDS","More videos from this category");
DEFINE("_HWDVIDS_CATEGORY","Category");
DEFINE("_HWDVIDS_NEXT","Next &raquo;");
DEFINE("_HWDVIDS_PREV","&laquo; Prev");
DEFINE("_HWDVIDS_TITLE_PERMALINK","Permalink");
DEFINE("_HWDVIDS_TITLE_MOREBYUSR","More videos from ");
DEFINE("_HWDVIDS_ALT_USRPRO","User Profile");
DEFINE("_HWDVIDS_TAGS","Tags");
DEFINE("_HWDVIDS_FLASHUPDL_allowedExtDescr","Allowed Video Files");
DEFINE("_HWDVIDS_FLASHUPDL_validFileMessage","Thank you! Now hit upload.");
DEFINE("_HWDVIDS_FLASHUPDL_startMessage","Select your video file");
DEFINE("_HWDVIDS_FLASHUPDL_errorSizeMessage","This file is too large!");
DEFINE("_HWDVIDS_FLASHUPDL_progressMessage","Please wait, uploading ");
DEFINE("_HWDVIDS_FLASHUPDL_endMessage","Upload finished!");
DEFINE("_HWDVIDS_UU_UIP","Upload In Progress");
DEFINE("_HWDVIDS_UU_PC","Percent Complete:");
DEFINE("_HWDVIDS_UU_FU","Files Uploaded:");
DEFINE("_HWDVIDS_UU_CP","Current Position:");
DEFINE("_HWDVIDS_UU_ET","Elapsed Time:");
DEFINE("_HWDVIDS_UU_ETL","Est Time Left:");
DEFINE("_HWDVIDS_UU_ES","Est Speed:");
DEFINE("_HWDVIDS_UU_IPB","Initialising Progress Bar ...");
DEFINE("_HWDVIDS_UU_NAJAXS","Warning: Your browser does not support AJAX");
DEFINE("_HWDVIDS_LINKS_BACK","&laquo; Back");
DEFINE("_HWDVIDS_WARNING_EJFU","Javascript must be enabled to use this uploader.");
DEFINE("_HWDVIDS_BACKLINK","Back");
DEFINE("_HWDVIDS_INFO_SUPPTPW","Videos from the following websites can be added.");
DEFINE("_HWDVIDS_ALERTSELGROUP","Please select a group first.");
DEFINE("_HWDVIDS_CN_NOUV","This user has not uploaded any videos.");
DEFINE("_HWDVIDS_CN_NOFV","This user has not got any favourite videos.");
DEFINE("_HWDVIDS_VSNOINS","hwdVideoShare is not installed. Please contact site administrator.");
DEFINE("_HWDVIDS_BTP","Back to Profile");
DEFINE("_HWDVIDS_ALERT_VIDNOEXIST","This video is currently not available for you to view. This could be for one of the following reasons:<ul><li>The video is currently not published</li><li>The video is still being converted after upload.</li><li>The video is pending approval from the website moderators</li><li>The video has been deleted</li><li>You need to login to view the video</li><li>Your account does not give you access to this video</li></ul>");
DEFINE("_HWDVIDS_VOV","View Original Video");
DEFINE("_HWDVIDS_NXBT","Next Button");
DEFINE("_HWDVIDS_PVBT","Previous Button");
DEFINE("_HWDVIDS_PGTNV","There has been a problem going to the next video.");
DEFINE("_HWDVIDS_PGTPV","There has been a problem going to the previous video.");
DEFINE("_HWDVIDS_TCDNE","This category does not exist.");
DEFINE("_HWDVIDS_ZSHAREWF","This zShare video does not appear to be in the Flash Video format, which means it can not be displayed.");
DEFINE("_HWDVIDS_JS_AS1","has uploaded");
DEFINE("_HWDVIDS_JS_AS2","a new");
DEFINE("_HWDVIDS_JS_AS3","video");
DEFINE("_HWDVIDS_JS_AS4","videos");
DEFINE("_HWDVIDS_JS_AS5","new");
DEFINE("_HWDVIDS_YHRTE","You have reached the end of this category, you can not go to the next video.");
DEFINE("_HWDVIDS_YHRTS","You have reached the start of this category, you can not go to the previous video.");
DEFINE("_HWDVIDS_FLASHUPDL_FUPLD"," has been processed. Your video is now being processed...");
DEFINE("_HWDVIDS_USERS_VIDEOS","User's Videos");
DEFINE("_HWDVIDS_GTVP","Go to video page");
DEFINE("_HWDVIDS_WARNING","Warning");
DEFINE("_HWDVIDS_VIDEOS","Videos");
DEFINE("_HWDVIDS_SUBCATS","Subcategories");
DEFINE("_HWDVIDS_SELECT_TEMPLATE","Select Template");
DEFINE("_HWDVIDS_DEFAULT_TEMPLATE","Default Template");
DEFINE("_HWDVIDS_INFO_SECURECODE","Security Code");
DEFINE("_HWDVIDS_ALERT_ADMIN_USERVIDDEL","Your video has been successfully removed");
DEFINE("_HWDVIDS_ALERT_NOEMBEDCODE","Please enter the URL of a video page.");
DEFINE("_HWDVIDS_UNREAD","UNREAD");
DEFINE("_HWDVIDS_ALERT_ADMIN_VIDUNPUB","The video has been unpublished");
DEFINE("_HWDVIDS_INFO_NOINS_JOOMLACOMMENT","The hwdVideoShare plugin for !JoomlaComment is not installed.");
DEFINE("_HWDVIDS_MODPA","Pending Approval");
DEFINE("_HWDVIDS_MODRV","Reported Videos");
DEFINE("_HWDVIDS_MODRG","Reported Groups");
DEFINE("_HWDVIDS_MORE","More");
DEFINE("_HWDVIDS_ADSEARCH","Advanced Search");

DEFINE("_HWDVIDS_VIDEOPLAYLISTS","Video Playlists");
DEFINE("_HWDVIDS_FEATVIDEOPLAYLISTS","Featured Video Playlists");

DEFINE("_HWDVIDS_SELECT_ME","Only Me");
DEFINE("_HWDVIDS_SELECT_PASSWORD","Password Protected");
DEFINE("_HWDVIDS_EDITCHANNEL","Edit Channel");
DEFINE("_HWDVIDS_INFO_NVC","No channels have been setup");

DEFINE("_HWDVIDS_PASSWORD","Password");
DEFINE("_HWDVIDS_ORUCAV","Only registered users can view this video");
DEFINE("_HWDVIDS_OOCAV","Only the owner can view this video");
DEFINE("_HWDVIDS_IPW","The password you entered is not valid");
DEFINE("_HWDVIDS_TVPP","This video is password protected");
DEFINE("_HWDVIDS_RECENTVIDEOS","Recent Videos");
DEFINE("_HWDVIDS_POPULARVIDEOS","Most Popular Videos");
DEFINE("_HWDVIDS_RATEDVIDEOS","Top Rated Videos");
DEFINE("_HWDVIDS_SENDFRIEND","Send to a friend");
DEFINE("_HWDVIDS_SELPL","Please select a playlist first");
DEFINE("_HWDVIDS_ALERT_NOPLNAME","Please enter a playlist name");
DEFINE("_HWDVIDS_ALERT_NOPLDESC","Please enter a playlist description");
DEFINE("_HWDVIDS_ALERT_PLREMOVED","Your playlist has been deleted");
DEFINE("_HWDVIDS_SUBSCRIBE","Subscribe");
DEFINE("_HWDVIDS_UNSUBSCRIBE","Unsubscribe");
DEFINE("_HWDVIDS_ASALL","Find videos with all these words");
DEFINE("_HWDVIDS_ASEXACT","Find videos with this exact wording or phrase");
DEFINE("_HWDVIDS_ASEX","But without any of these unwanted words");
DEFINE("_HWDVIDS_RPP","Results per page");
DEFINE("_HWDVIDS_ORGANISE","Organise");
DEFINE("_HWDVIDS_RELEVANCE","Relevance");
DEFINE("_HWDVIDS_MOREVIDEOS","More Videos");
DEFINE("_HWDVIDS_COMMENTS","comments");

DEFINE("_HWDVIDS_AGEGATE","This video is age restricted.");
DEFINE("_HWDVIDS_AGEGATE_ENTER","Please enter your date of birth.");
DEFINE("_HWDVIDS_AGEGATE_INVALID","The date you entered is not valid.");
DEFINE("_HWDVIDS_AGEGATE_TOOYOUNG","You are too young to watch this video.");

DEFINE("_HWDVIDS_RATE_1STAR","Very poor");
DEFINE("_HWDVIDS_RATE_2STAR","Fair");
DEFINE("_HWDVIDS_RATE_3STAR","Average");
DEFINE("_HWDVIDS_RATE_4STAR","Good");
DEFINE("_HWDVIDS_RATE_5STAR","Excellent");

DEFINE("_HWDVIDS_VIEWED","Viewed");
DEFINE("_HWDVIDS_POPULAR","Popular");
DEFINE("_HWDVIDS_FAVOURED","Favoured");

DEFINE("_HWDVIDS_NVPA","No videos are pending approval.");
DEFINE("_HWDVIDS_ALERT_LOG2ADDC","You must login to create a channel.");

DEFINE("_HWDVIDS_LB_GC","Get Connected!");
DEFINE("_HWDVIDS_LB_1","Share your videos and photos");
DEFINE("_HWDVIDS_LB_2","Connect and expand your network");
DEFINE("_HWDVIDS_LB_3","View community videos and photos");
DEFINE("_HWDVIDS_LB_4","Create your own video and photos groups");
DEFINE("_HWDVIDS_LB_JOIN","Join Our Website Now!");
DEFINE("_HWDVIDS_LB_U","Username");
DEFINE("_HWDVIDS_LB_P","Password");
DEFINE("_HWDVIDS_LB_RM","Remember my details");
DEFINE("_HWDVIDS_LB_L","Login");
DEFINE("_HWDVIDS_LB_FP","Forgot your password?");
DEFINE("_HWDVIDS_LB_FU","Forgot your username?");

DEFINE("_HWDVIDS_WTYNC","Welcome to your new channel");
DEFINE("_HWDVIDS_EYC","Edit your channel");
DEFINE("_HWDVIDS_YOURSTYLE","Your Style");
DEFINE("_HWDVIDS_YOURPREFERENCES","Your Preferences");
DEFINE("_HWDVIDS_YOURCHANNEL","Your Channel");
DEFINE("_HWDVIDS_YOURLOGO","Your Logo");
DEFINE("_HWDVIDS_YOURLOGO_DESC","You can upload a new logo for your channel. Uploads are limited to 2MB.");
DEFINE("_HWDVIDS_VIDEOCHANNELS","Video Channels");

DEFINE("_HWDVIDS_FAVOURITEVIDEOS","Favourite Videos");
DEFINE("_HWDVIDS_RECENTLYVIEWED","Recently Viewed");
DEFINE("_HWDVIDS_CHANNELVIEWS","Channel Views");
DEFINE("_HWDVIDS_TOTALUPLOADS","Total Uploads");
DEFINE("_HWDVIDS_JOINED","Joined");
DEFINE("_HWDVIDS_LASTVISIT","Last Sign In");
DEFINE("_HWDVIDS_SUBCRIBERS","Subscribers");

DEFINE("_HWDVIDS_NOUV","No user videos");
DEFINE("_HWDVIDS_NOUP","No user playlists");
DEFINE("_HWDVIDS_NOUG","No user groups");

DEFINE("_HWDVIDS_C_UPLOADS","%s's uploaded videos");
DEFINE("_HWDVIDS_C_FAVOURITES","%s's favourite videos");
DEFINE("_HWDVIDS_C_VIEWED","%s's recently viewed videos");
DEFINE("_HWDVIDS_C_LIKED","%s's recently liked videos");
DEFINE("_HWDVIDS_C_DISLIKED","%s's recently disliked videos");
DEFINE("_HWDVIDS_C_GROUPS","%s's groups");
DEFINE("_HWDVIDS_C_PLAYLISTS","%s's playlists");
DEFINE("_HWDVIDS_C_MEMBERSHIPS","%s's memberships");
DEFINE("_HWDVIDS_C_SUBSCRIPTIONS","%s's subscriptions");
DEFINE("_HWDVIDS_C_TITLE","%s's Channel");


